@@ -26,8 +26,13 @@
 
 /*----------------------------------------------------------------------------*/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib.h>
 #include <glib-object.h>
+#include <glib/gi18n-lib.h>
 
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-camel.h>
@@ -72,11 +77,11 @@ G_DEFINE_TYPE (EBookBackendKolab, e_book_backend_kolab, E_TYPE_BOOK_BACKEND_SYNC
 /* forward declarations */
 
 static void
-e_book_backend_kolab_open (EBookBackendSync *backend,
-                           EDataBook *book,
-                           GCancellable *cancellable,
-                           gboolean only_if_exists,
-                           GError **error);
+book_backend_kolab_open (EBookBackendSync *backend,
+                         EDataBook *book,
+                         GCancellable *cancellable,
+                         gboolean only_if_exists,
+                         GError **error);
 
 /*----------------------------------------------------------------------------*/
 /* internal statics */
@@ -166,7 +171,7 @@ book_backend_kolab_signal_online_cb (GObject *object)
 
 	(void) kolab_util_backend_deploy_mode_by_backend (priv->book_koma,
 	                                                  online,
-	                                                  NULL, /* GCancellable (see above )*/
+	                                                  NULL, /* GCancellable (see above) */
 	                                                  &(priv->mode_switch_err));
 	if (priv->mode_switch_err) {
 		g_warning ("%s()[%u]: Online mode switching error pending, (%s), Domain %s Code %i",
@@ -224,24 +229,24 @@ book_backend_kolab_notify_removed (EBookBackendKolab *self)
 /* class functions */
 
 static void
-e_book_backend_kolab_open (EBookBackendSync *backend,
-                           EDataBook *book,
-                           GCancellable *cancellable,
-                           gboolean only_if_exists,
-                           GError **error)
+book_backend_kolab_open (EBookBackendSync *backend,
+                         EDataBook *book,
+                         GCancellable *cancellable,
+                         gboolean only_if_exists,
+                         GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
-	ESourceRegistry *registry;
+	ESourceRegistry *registry = NULL;
 	ESource *esource = NULL;
-	ESourceKolabFolder *extension;
-	CamelKolabIMAPXSettings *kolab_settings;
-	CamelNetworkSettings *network_settings;
+	ESourceKolabFolder *extension = NULL;
+	CamelKolabIMAPXSettings *kolab_settings = NULL;
+	CamelNetworkSettings *network_settings = NULL;
 	KolabSettingsHandler *ksettings = NULL;
 	KolabMailAccess *tmp_koma = NULL;
 	KolabSyncStrategyID sync_value = KOLAB_SYNC_STRATEGY_DEFAULT;
-	const gchar *extension_name;
-	const gchar *foldername;
+	const gchar *extension_name = NULL;
+	const gchar *foldername = NULL;
 	gchar *servername = NULL;
 	gchar *username = NULL;
 	gchar *user_at_server = NULL;
@@ -266,9 +271,8 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 
 	esource = e_backend_get_source (E_BACKEND (backend));
 	if (! E_IS_SOURCE (esource)) {
-		/* FIXME mark this as a translatable string */
 		tmp_err = e_data_book_create_error (E_DATA_BOOK_STATUS_OTHER_ERROR,
-		                                    "Could not get ESource for backend");
+		                                    _("Could not get ESource for backend"));
 		goto exit;
 	}
 
@@ -434,10 +438,10 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 }
 
 static void
-e_book_backend_kolab_remove (EBookBackendSync *backend,
-                             EDataBook *book,
-                             GCancellable *cancellable,
-                             GError **error)
+book_backend_kolab_remove (EBookBackendSync *backend,
+                           EDataBook *book,
+                           GCancellable *cancellable,
+                           GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -469,10 +473,10 @@ e_book_backend_kolab_remove (EBookBackendSync *backend,
 }
 
 static void
-e_book_backend_kolab_refresh (EBookBackendSync *backend,
-                              EDataBook *book,
-                              GCancellable *cancellable,
-                              GError **error)
+book_backend_kolab_refresh (EBookBackendSync *backend,
+                            EDataBook *book,
+                            GCancellable *cancellable,
+                            GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -490,12 +494,12 @@ e_book_backend_kolab_refresh (EBookBackendSync *backend,
 
 #if 0 /* probably not needed */
 static gboolean
-e_book_backend_kolab_get_backend_property (EBookBackendSync *backend,
-                                           EDataBook *book,
-                                           GCancellable *cancellable,
-                                           const gchar *prop_name,
-                                           gchar **prop_value,
-                                           GError **error)
+book_backend_kolab_get_backend_property (EBookBackendSync *backend,
+                                         EDataBook *book,
+                                         GCancellable *cancellable,
+                                         const gchar *prop_name,
+                                         gchar **prop_value,
+                                         GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -518,12 +522,12 @@ e_book_backend_kolab_get_backend_property (EBookBackendSync *backend,
 
 #if 0 /* probably not needed */
 static gboolean
-e_book_backend_kolab_set_backend_property (EBookBackendSync *backend,
-                                           EDataBook *book,
-                                           GCancellable *cancellable,
-                                           const gchar *prop_name,
-                                           const gchar *prop_value,
-                                           GError **error)
+book_backend_kolab_set_backend_property (EBookBackendSync *backend,
+                                         EDataBook *book,
+                                         GCancellable *cancellable,
+                                         const gchar *prop_name,
+                                         const gchar *prop_value,
+                                         GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -543,12 +547,12 @@ e_book_backend_kolab_set_backend_property (EBookBackendSync *backend,
 #endif
 
 static void
-e_book_backend_kolab_create_contacts (EBookBackendSync *backend,
-                                      EDataBook *book,
-                                      GCancellable *cancellable,
-                                      const GSList *vcards,
-                                      GSList **added_contacts,
-                                      GError **error)
+book_backend_kolab_create_contacts (EBookBackendSync *backend,
+                                    EDataBook *book,
+                                    GCancellable *cancellable,
+                                    const GSList *vcards,
+                                    GSList **added_contacts,
+                                    GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -609,12 +613,12 @@ e_book_backend_kolab_create_contacts (EBookBackendSync *backend,
 }
 
 static void
-e_book_backend_kolab_remove_contacts (EBookBackendSync *backend,
-                                      EDataBook *book,
-                                      GCancellable *cancellable,
-                                      const GSList *id_list,
-                                      GSList **removed_ids,
-                                      GError **error)
+book_backend_kolab_remove_contacts (EBookBackendSync *backend,
+                                    EDataBook *book,
+                                    GCancellable *cancellable,
+                                    const GSList *id_list,
+                                    GSList **removed_ids,
+                                    GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -662,12 +666,12 @@ e_book_backend_kolab_remove_contacts (EBookBackendSync *backend,
 }
 
 static void
-e_book_backend_kolab_modify_contacts (EBookBackendSync *backend,
-                                      EDataBook *book,
-                                      GCancellable *cancellable,
-                                      const GSList *vcards,
-                                      GSList **modified_contacts,
-                                      GError **error)
+book_backend_kolab_modify_contacts (EBookBackendSync *backend,
+                                    EDataBook *book,
+                                    GCancellable *cancellable,
+                                    const GSList *vcards,
+                                    GSList **modified_contacts,
+                                    GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -719,12 +723,12 @@ e_book_backend_kolab_modify_contacts (EBookBackendSync *backend,
 }
 
 static void
-e_book_backend_kolab_get_contact (EBookBackendSync *backend,
-                                  EDataBook *book,
-                                  GCancellable *cancellable,
-                                  const gchar *id,
-                                  gchar **vcard,
-                                  GError **error)
+book_backend_kolab_get_contact (EBookBackendSync *backend,
+                                EDataBook *book,
+                                GCancellable *cancellable,
+                                const gchar *id,
+                                gchar **vcard,
+                                GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -761,12 +765,12 @@ e_book_backend_kolab_get_contact (EBookBackendSync *backend,
 }
 
 static void
-e_book_backend_kolab_get_contact_list (EBookBackendSync *backend,
-                                       EDataBook *book,
-                                       GCancellable *cancellable,
-                                       const gchar *query,
-                                       GSList **contacts,
-                                       GError **error)
+book_backend_kolab_get_contact_list (EBookBackendSync *backend,
+                                     EDataBook *book,
+                                     GCancellable *cancellable,
+                                     const gchar *query,
+                                     GSList **contacts,
+                                     GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -824,12 +828,12 @@ e_book_backend_kolab_get_contact_list (EBookBackendSync *backend,
 }
 
 static void
-e_book_backend_kolab_get_contact_list_uids (EBookBackendSync *backend,
-                                            EDataBook *book,
-                                            GCancellable *cancellable,
-                                            const gchar *query,
-                                            GSList **contacts_uids,
-                                            GError **error)
+book_backend_kolab_get_contact_list_uids (EBookBackendSync *backend,
+                                          EDataBook *book,
+                                          GCancellable *cancellable,
+                                          const gchar *query,
+                                          GSList **contacts_uids,
+                                          GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -897,12 +901,12 @@ e_book_backend_kolab_get_contact_list_uids (EBookBackendSync *backend,
 }
 
 static gboolean
-e_book_backend_kolab_get_backend_property (EBookBackendSync *backend,
-                                           EDataBook *book,
-                                           GCancellable *cancellable,
-                                           const gchar *prop_name,
-                                           gchar **prop_value,
-                                           GError **error)
+book_backend_kolab_get_backend_property (EBookBackendSync *backend,
+                                         EDataBook *book,
+                                         GCancellable *cancellable,
+                                         const gchar *prop_name,
+                                         gchar **prop_value,
+                                         GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -944,10 +948,10 @@ e_book_backend_kolab_get_backend_property (EBookBackendSync *backend,
 #if 0  /* FIXME Delete this once kolab_mail_access_try_password_sync()
         *       works.  There may be code here that can be reused. */
 static void
-e_book_backend_kolab_authenticate_user (EBookBackendSync *backend,
-                                        GCancellable *cancellable,
-                                        ECredentials *credentials,
-                                        GError **error)
+book_backend_kolab_authenticate_user (EBookBackendSync *backend,
+                                      GCancellable *cancellable,
+                                      ECredentials *credentials,
+                                      GError **error)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -1066,8 +1070,8 @@ e_book_backend_kolab_authenticate_user (EBookBackendSync *backend,
 #endif
 
 static void
-e_book_backend_kolab_start_book_view (EBookBackend *backend,
-                                      EDataBookView *book_view)
+book_backend_kolab_start_book_view (EBookBackend *backend,
+                                    EDataBookView *book_view)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -1134,8 +1138,8 @@ e_book_backend_kolab_start_book_view (EBookBackend *backend,
 }
 
 static void
-e_book_backend_kolab_stop_book_view (EBookBackend *backend,
-                                     EDataBookView *book_view)
+book_backend_kolab_stop_book_view (EBookBackend *backend,
+                                   EDataBookView *book_view)
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
@@ -1237,23 +1241,23 @@ e_book_backend_kolab_class_init (EBookBackendKolabClass *klass)
 	object_class->finalize = e_book_backend_kolab_finalize;
 
 	/* Backend parent class methods methods not covered in the sync backend part */
-	backend_class->start_book_view = e_book_backend_kolab_start_book_view;
-	backend_class->stop_book_view = e_book_backend_kolab_stop_book_view;
+	backend_class->start_book_view = book_backend_kolab_start_book_view;
+	backend_class->stop_book_view = book_backend_kolab_stop_book_view;
 
 	/* Sync backend class functions */
-	sync_class->open_sync = e_book_backend_kolab_open;
-	sync_class->remove_sync = e_book_backend_kolab_remove;
-	sync_class->refresh_sync = e_book_backend_kolab_refresh;
-	sync_class->get_backend_property_sync = e_book_backend_kolab_get_backend_property;
+	sync_class->open_sync = book_backend_kolab_open;
+	sync_class->remove_sync = book_backend_kolab_remove;
+	sync_class->refresh_sync = book_backend_kolab_refresh;
+	sync_class->get_backend_property_sync = book_backend_kolab_get_backend_property;
 #if 0 /* probably not needed */
-	sync_class->set_backend_property_sync = e_book_backend_kolab_set_backend_property;
+	sync_class->set_backend_property_sync = book_backend_kolab_set_backend_property;
 #endif
-	sync_class->create_contacts_sync = e_book_backend_kolab_create_contacts;
-	sync_class->remove_contacts_sync = e_book_backend_kolab_remove_contacts;
-	sync_class->modify_contacts_sync = e_book_backend_kolab_modify_contacts;
-	sync_class->get_contact_sync = e_book_backend_kolab_get_contact;
-	sync_class->get_contact_list_sync = e_book_backend_kolab_get_contact_list;
-	sync_class->get_contact_list_uids_sync = e_book_backend_kolab_get_contact_list_uids;
+	sync_class->create_contacts_sync = book_backend_kolab_create_contacts;
+	sync_class->remove_contacts_sync = book_backend_kolab_remove_contacts;
+	sync_class->modify_contacts_sync = book_backend_kolab_modify_contacts;
+	sync_class->get_contact_sync = book_backend_kolab_get_contact;
+	sync_class->get_contact_list_sync = book_backend_kolab_get_contact_list;
+	sync_class->get_contact_list_uids_sync = book_backend_kolab_get_contact_list_uids;
 } /* e_book_backend_kolab_class_init () */
 
 
@@ -1262,51 +1266,3 @@ e_book_backend_kolab_class_init (EBookBackendKolabClass *klass)
 
 
 /*----------------------------------------------------------------------------*/
-
-#if 0 /* FIXME old */
-
-/**
- * e_book_backend_kolab_set_mode:
- * @backend: A Kolab addressbook backend.
- * @mode: Mode to change to.
- *
- * Sets the mode of the addressbook backend to the given mode.
- */
-static void
-e_book_backend_kolab_set_mode (EBookBackend *backend,
-                               GNOME_Evolution_Addressbook_BookMode mode)
-{
-	EBookBackendKolab *kolab = E_BOOK_BACKEND_KOLAB (backend);
-	EBookBackendKolabPrivate *priv = E_BOOK_BACKEND_KOLAB_PRIVATE (kolab);
-	KolabMailAccessOpmodeID koma_mode;
-	KolabMailAccessOpmodeID tmp_mode;
-	g_debug ("%s()[%u] called with mode: %u.", __func__, __LINE__, mode);
-	switch (mode) {
-	case GNOME_Evolution_Addressbook_MODE_ANY:
-	case GNOME_Evolution_Addressbook_MODE_REMOTE:
-		g_debug (" + got argument E_DATA_BOOK_MODE_ANY/E_DATA_BOOK_MODE_REMOTE, "
-		         "switching backend_mode to E_DATA_BOOK_MODE_REMOTE.");
-		priv->book_mode = GNOME_Evolution_Addressbook_MODE_REMOTE;
-		koma_mode = KOLAB_MAIL_ACCESS_OPMODE_ONLINE;
-		break;
-	case GNOME_Evolution_Addressbook_MODE_LOCAL:
-		g_debug (" + got argument E_DATA_BOOK_MODE_LOCAL, switching backend_mode.");
-		priv->book_mode = GNOME_Evolution_Addressbook_MODE_LOCAL;
-		koma_mode = KOLAB_MAIL_ACCESS_OPMODE_OFFLINE;
-		break;
-	default:
-		g_error ("%s() ran into an unknown arguments for mode, value %u. "
-		         "This should not happen.", __func__, mode);
-	}
-
-	if (priv->auth_received == TRUE)
-		tmp_mode = kolab_util_backend_deploy_mode_by_koma (priv->book_koma,
-		                                                   koma_mode);
-	else
-		tmp_mode = KOLAB_MAIL_ACCESS_OPMODE_OFFLINE;
-
-	e_book_backend_notify_connection_status (backend,
-	                                         tmp_mode = KOLAB_MAIL_ACCESS_OPMODE_ONLINE ? TRUE : FALSE);
-} /* e_book_backend_kolab_set_mode () */
-
-#endif /* FIXME old */
