@@ -27,8 +27,7 @@
 
 #include <libekolab/kolab-mail-access.h>
 
-#include <libebook/e-contact.h>
-#include <libecal/e-cal.h>
+#include <libecal/libecal.h>
 
 #include "kolab-util-contact.h"
 
@@ -129,30 +128,30 @@ kolab_util_contact_gen_uid_if_none (EContact **contact)
 
 gboolean
 kolab_util_contact_store (EContact *econtact,
+                          EBookBackendSync *backend,
                           KolabMailAccess *koma,
-                          const gchar *uri,
                           GCancellable *cancellable,
                           GError **error)
 {
-	const gchar *sourcename = NULL;
+	const gchar *foldername = NULL;
 	KolabMailHandle *kmh = NULL;
 	GError *tmp_error = NULL;
 	gboolean ok = FALSE;
 
 	g_assert (E_IS_CONTACT (econtact));
+	g_assert (E_IS_BOOK_BACKEND (backend));
 	g_assert (KOLAB_IS_MAIL_ACCESS (koma));
-	g_assert (uri != NULL);
 	/* cancellable may be NULL */
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	kolab_util_backend_modtime_set_on_econtact (econtact);
 	kmh = kolab_mail_handle_new_from_econtact (econtact);
 
 	ok =  kolab_mail_access_store_handle (koma,
 	                                      kmh,
-	                                      sourcename,
+	                                      foldername,
 	                                      cancellable,
 	                                      &tmp_error);
 	if (! ok) {
@@ -264,7 +263,7 @@ kolab_utils_contact_get_supported_fields (void)
 		fields = g_slist_append (fields, (gpointer) e_contact_field_name (mappings[ii].field_id));
 	}
 
-	fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_BOOK_URI));
+	fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_BOOK_UID));
 
 	return fields;
 }
