@@ -34,9 +34,8 @@
 #include <gio/gio.h>
 #include <glib-object.h>
 
-#include <libebook/e-contact.h>
-#include <libedata-book/e-data-book-types.h>
-#include <libedata-book/e-book-backend-sync.h>
+#include <libebook/libebook.h>
+#include <libedata-book/libedata-book.h>
 
 #include <libekolab/kolab-mail-access.h>
 
@@ -54,8 +53,8 @@ kolab_util_contact_gen_uid_if_none (EContact **contact);
 
 gboolean
 kolab_util_contact_store (EContact *econtact,
+                          EBookBackendSync *backend,
                           KolabMailAccess *koma,
-                          const gchar *uri,
                           GCancellable *cancellable,
                           GError **error);
 
