@@ -33,7 +33,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <libedata-cal/e-cal-backend-factory.h>
+#include <libedata-cal/libedata-cal.h>
 #include <libekolabutil/kolab-util-camel.h>
 
 #include "e-cal-backend-kolab.h"
