@@ -26,8 +26,13 @@
 
 /*----------------------------------------------------------------------------*/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib.h>
 #include <gio/gio.h>
+#include <glib/gi18n-lib.h>
 
 #include <libecal/libecal.h>
 
@@ -58,18 +63,18 @@ static GMutex active_cal_views_lock;
 /* forward declarations */
 
 static void
-e_cal_backend_kolab_add_timezone (ECalBackendSync *backend,
-                                  EDataCal *cal,
-                                  GCancellable *cancellable,
-                                  const gchar *tzobject,
-                                  GError **error);
+cal_backend_kolab_add_timezone (ECalBackendSync *backend,
+                                EDataCal *cal,
+                                GCancellable *cancellable,
+                                const gchar *tzobject,
+                                GError **error);
 
 static void
-e_cal_backend_kolab_open (ECalBackendSync *backend,
-                          EDataCal *cal,
-                          GCancellable *cancellable,
-                          gboolean only_if_exists,
-                          GError **error);
+cal_backend_kolab_open (ECalBackendSync *backend,
+                        EDataCal *cal,
+                        GCancellable *cancellable,
+                        gboolean only_if_exists,
+                        GError **error);
 
 /*----------------------------------------------------------------------------*/
 
@@ -237,7 +242,7 @@ cal_backend_kolab_notify_removed (ECalBackendKolab *self)
 /* class functions */
 
 /**
- * e_cal_backend_kolab_open:
+ * cal_backend_kolab_open:
  * @backend: An ECalBackendSync object.
  * @cal: An EDataCal object.
  * @cancellable: A cancellation stack.
@@ -248,27 +253,27 @@ cal_backend_kolab_notify_removed (ECalBackendKolab *self)
  * Opens a calendar backend with data from a calendar stored at the specified URI.
  */
 static void
-e_cal_backend_kolab_open (ECalBackendSync *backend,
-                          EDataCal *cal,
-                          GCancellable *cancellable,
-                          gboolean only_if_exists,
-                          GError **error)
+cal_backend_kolab_open (ECalBackendSync *backend,
+                        EDataCal *cal,
+                        GCancellable *cancellable,
+                        gboolean only_if_exists,
+                        GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
-	ESourceRegistry *registry;
+	ESourceRegistry *registry = NULL;
 	ESource *esource = NULL;
-	ESourceKolabFolder *extension;
-	CamelKolabIMAPXSettings *kolab_settings;
-	CamelNetworkSettings *network_settings;
+	ESourceKolabFolder *extension = NULL;
+	CamelKolabIMAPXSettings *kolab_settings = NULL;
+	CamelNetworkSettings *network_settings = NULL;
 	KolabSettingsHandler *ksettings = NULL;
 	KolabMailAccess *tmp_koma = NULL;
 	KolabSyncStrategyID sync_value = KOLAB_SYNC_STRATEGY_DEFAULT;
 	icalcomponent_kind icalkind = ICAL_VEVENT_COMPONENT;
-	const gchar *extension_name;
-	const gchar *foldername;
-	const gchar *cache_dir;
-	gchar *cache_filename;
+	const gchar *extension_name = NULL;
+	const gchar *foldername = NULL;
+	const gchar *cache_dir = NULL;
+	gchar *cache_filename = NULL;
 	gchar *servername = NULL;
 	gchar *username = NULL;
 	gchar *user_at_server = NULL;
@@ -307,15 +312,14 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 		g_set_error (&tmp_err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_GENERIC,
-		             "Unknown type used in e-cal-backend-kolab initialization");
+		             _("Unknown type used in e-cal-backend-kolab initialization"));
 		goto exit;
 	}
 
 	esource = e_backend_get_source (E_BACKEND (backend));
 	if (! E_IS_SOURCE (esource)) {
-		/* FIXME mark this as a translatable string */
 		tmp_err = e_data_cal_create_error (OtherError,
-		                                   "Could not get ESource for backend");
+		                                   _("Could not get ESource for backend"));
 		goto exit;
 	}
 
@@ -500,10 +504,10 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_remove (ECalBackendSync *backend,
-                            EDataCal *cal,
-                            GCancellable *cancellable,
-                            GError **error)
+cal_backend_kolab_remove (ECalBackendSync *backend,
+                          EDataCal *cal,
+                          GCancellable *cancellable,
+                          GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	/* ECalBackendKolabPrivate *priv = NULL; */
@@ -536,10 +540,10 @@ e_cal_backend_kolab_remove (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_refresh (ECalBackendSync *backend,
-                             EDataCal *cal,
-                             GCancellable *cancellable,
-                             GError **error)
+cal_backend_kolab_refresh (ECalBackendSync *backend,
+                           EDataCal *cal,
+                           GCancellable *cancellable,
+                           GError **error)
 {
 	/* ECalBackendKolab *self = NULL; */
 	/* ECalBackendKolabPrivate *priv = NULL; */
@@ -556,12 +560,12 @@ e_cal_backend_kolab_refresh (ECalBackendSync *backend,
 }
 
 static gboolean
-e_cal_backend_kolab_get_backend_property (ECalBackendSync *backend,
-                                          EDataCal *cal,
-                                          GCancellable *cancellable,
-                                          const gchar *prop_name,
-                                          gchar **prop_value,
-                                          GError **error)
+cal_backend_kolab_get_backend_property (ECalBackendSync *backend,
+                                        EDataCal *cal,
+                                        GCancellable *cancellable,
+                                        const gchar *prop_name,
+                                        gchar **prop_value,
+                                        GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -634,12 +638,12 @@ e_cal_backend_kolab_get_backend_property (ECalBackendSync *backend,
 
 #if 0 /* probably not needed */
 static gboolean
-e_cal_backend_kolab_set_backend_property (ECalBackendSync *backend,
-                                          EDataCal *cal,
-                                          GCancellable *cancellable,
-                                          const gchar *prop_name,
-                                          const gchar *prop_value,
-                                          GError **error)
+cal_backend_kolab_set_backend_property (ECalBackendSync *backend,
+                                        EDataCal *cal,
+                                        GCancellable *cancellable,
+                                        const gchar *prop_name,
+                                        const gchar *prop_value,
+                                        GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -661,7 +665,7 @@ e_cal_backend_kolab_set_backend_property (ECalBackendSync *backend,
 #endif
 
 /**
- * e_cal_backend_kolab_get_object:
+ * cal_backend_kolab_get_object:
  * @backend: An ECalBackendSync object.
  * @cal: An EDataCal object.
  * @cancellable: A cancellation stack.
@@ -675,13 +679,13 @@ e_cal_backend_kolab_set_backend_property (ECalBackendSync *backend,
  * identifier and its recurrence ID (if a recurrent appointment).
  */
 static void
-e_cal_backend_kolab_get_object (ECalBackendSync *backend,
-                                EDataCal *cal,
-                                GCancellable *cancellable,
-                                const gchar *uid,
-                                const gchar *rid,
-                                gchar **calobj,
-                                GError **error)
+cal_backend_kolab_get_object (ECalBackendSync *backend,
+                              EDataCal *cal,
+                              GCancellable *cancellable,
+                              const gchar *uid,
+                              const gchar *rid,
+                              gchar **calobj,
+                              GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -718,12 +722,12 @@ e_cal_backend_kolab_get_object (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_get_object_list (ECalBackendSync *backend,
-                                     EDataCal *cal,
-                                     GCancellable *cancellable,
-                                     const gchar *sexp,
-                                     GSList **calobjs,
-                                     GError **error)
+cal_backend_kolab_get_object_list (ECalBackendSync *backend,
+                                   EDataCal *cal,
+                                   GCancellable *cancellable,
+                                   const gchar *sexp,
+                                   GSList **calobjs,
+                                   GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -807,14 +811,14 @@ e_cal_backend_kolab_get_object_list (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
-                                   EDataCal *cal,
-                                   GCancellable *cancellable,
-                                   const GSList *users,
-                                   time_t start,
-                                   time_t end,
-                                   GSList **freebusyobjs,
-                                   GError **error)
+cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
+                                 EDataCal *cal,
+                                 GCancellable *cancellable,
+                                 const GSList *users,
+                                 time_t start,
+                                 time_t end,
+                                 GSList **freebusyobjs,
+                                 GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -890,7 +894,7 @@ e_cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
 }
 
 /**
- * e_cal_backend_kolab_create_objects:
+ * cal_backend_kolab_create_objects:
  * @backend: (sync) kolab calendar backend object.
  * @cal: An EDataCal object.
  * @cancellable: A cancellation stack
@@ -903,13 +907,13 @@ e_cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
  * when Evolution requests a new entry to be saved in the calendar.
  */
 static void
-e_cal_backend_kolab_create_objects (ECalBackendSync *backend,
-                                    EDataCal *cal,
-                                    GCancellable *cancellable,
-                                    const GSList *calobjs,
-                                    GSList **uids,
-                                    GSList **new_components,
-                                    GError **error)
+cal_backend_kolab_create_objects (ECalBackendSync *backend,
+                                  EDataCal *cal,
+                                  GCancellable *cancellable,
+                                  const GSList *calobjs,
+                                  GSList **uids,
+                                  GSList **new_components,
+                                  GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -928,7 +932,7 @@ e_cal_backend_kolab_create_objects (ECalBackendSync *backend,
 	e_return_data_cal_error_if_fail (new_components != NULL && *new_components == NULL, InvalidArg);
 
 	if (calobjs->next) {
-		g_propagate_error (error, e_data_cal_create_error (UnsupportedMethod, "Kolab does not support bulk additions"));
+		g_propagate_error (error, e_data_cal_create_error (UnsupportedMethod, _("Kolab does not support bulk additions")));
 		return;
 	}
 
@@ -969,9 +973,8 @@ e_cal_backend_kolab_create_objects (ECalBackendSync *backend,
 			 */
 			g_free (tzid);
 			g_object_unref (ecalcomp);
-			/* FIXME mark this as a translatable string */
 			tmp_err = e_data_cal_create_error (InvalidObject,
-			                                   "TZID is set, but no timezone is available. Currently this may happen if an object is copied to an empty calendar.");
+			                                   _("TZID is set, but no timezone is available. Currently this may happen if an object is copied to an empty calendar."));
 			g_propagate_error (error, tmp_err);
 			return;
 		}
@@ -1029,7 +1032,7 @@ e_cal_backend_kolab_create_objects (ECalBackendSync *backend,
 }
 
 /**
- * e_cal_backend_kolab_modify_objects:
+ * cal_backend_kolab_modify_objects:
  * @backend: An ECalBackendSync object.
  * @cal: An EDataCal object.
  * @cancellable: A cancellation stack.
@@ -1045,14 +1048,14 @@ e_cal_backend_kolab_create_objects (ECalBackendSync *backend,
  * does not exist on the calendar, it will be issued as new event.
  */
 static void
-e_cal_backend_kolab_modify_objects (ECalBackendSync *backend,
-                                    EDataCal *cal,
-                                    GCancellable *cancellable,
-                                    const GSList *calobjs,
-                                    CalObjModType mod,
-                                    GSList **old_components,
-                                    GSList **new_components,
-                                    GError **error)
+cal_backend_kolab_modify_objects (ECalBackendSync *backend,
+                                  EDataCal *cal,
+                                  GCancellable *cancellable,
+                                  const GSList *calobjs,
+                                  CalObjModType mod,
+                                  GSList **old_components,
+                                  GSList **new_components,
+                                  GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -1222,7 +1225,7 @@ e_cal_backend_kolab_modify_objects (ECalBackendSync *backend,
 }
 
 /**
- * e_cal_backend_kolab_remove_objects:
+ * cal_backend_kolab_remove_objects:
  * @backend: An ECalBackendSync object.
  * @cal: An EDataCal object.
  * @cancellable: A cancellation stack.
@@ -1239,14 +1242,14 @@ e_cal_backend_kolab_modify_objects (ECalBackendSync *backend,
  * backend will notify all of its clients about the change.
  */
 static void
-e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
-                                    EDataCal *cal,
-                                    GCancellable *cancellable,
-                                    const GSList *ids,
-                                    CalObjModType mod,
-                                    GSList **old_components,
-                                    GSList **new_components,
-                                    GError **error)
+cal_backend_kolab_remove_objects (ECalBackendSync *backend,
+                                  EDataCal *cal,
+                                  GCancellable *cancellable,
+                                  const GSList *ids,
+                                  CalObjModType mod,
+                                  GSList **old_components,
+                                  GSList **new_components,
+                                  GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -1271,7 +1274,7 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 	e_return_data_cal_error_if_fail (new_components != NULL && *new_components == NULL, InvalidArg);
 
 	if (ids->next) {
-		g_propagate_error (error, e_data_cal_create_error (UnsupportedMethod, "Kolab does not support bulk removals"));
+		g_propagate_error (error, e_data_cal_create_error (UnsupportedMethod, _("Kolab does not support bulk removals")));
 		return;
 	}
 
@@ -1414,7 +1417,7 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 }
 
 /**
- * e_cal_backend_kolab_receive_objects:
+ * cal_backend_kolab_receive_objects:
  * @backend: An ECalBackendSync object.
  * @cal: An EDataCal object.
  * @cancellable: A cancellation stack.
@@ -1424,11 +1427,11 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
  * Submits a (series of) calendar event(s) through iCalendar object(s).
  */
 static void
-e_cal_backend_kolab_receive_objects (ECalBackendSync *backend,
-                                     EDataCal *cal,
-                                     GCancellable *cancellable,
-                                     const gchar *calobj,
-                                     GError **error)
+cal_backend_kolab_receive_objects (ECalBackendSync *backend,
+                                   EDataCal *cal,
+                                   GCancellable *cancellable,
+                                   const gchar *calobj,
+                                   GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -1511,11 +1514,11 @@ e_cal_backend_kolab_receive_objects (ECalBackendSync *backend,
 	if (tzcomp != NULL) {
 		tzstr = e_cal_component_get_as_string (tzcomp);
 		g_object_unref (tzcomp);
-		e_cal_backend_kolab_add_timezone (backend,
-		                                  cal,
-		                                  cancellable,
-		                                  tzstr,
-		                                  &tmp_err);
+		cal_backend_kolab_add_timezone (backend,
+		                                cal,
+		                                cancellable,
+		                                tzstr,
+		                                &tmp_err);
 		if (tmp_err != NULL) {
 			kolab_util_calendar_err_to_edb_err (error,
 			                                    tmp_err,
@@ -1532,13 +1535,13 @@ e_cal_backend_kolab_receive_objects (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_send_objects (ECalBackendSync *backend,
-                                  EDataCal *cal,
-                                  GCancellable *cancellable,
-                                  const gchar *calobj,
-                                  GSList **users,
-                                  gchar **modified_calobj,
-                                  GError **error)
+cal_backend_kolab_send_objects (ECalBackendSync *backend,
+                                EDataCal *cal,
+                                GCancellable *cancellable,
+                                const gchar *calobj,
+                                GSList **users,
+                                gchar **modified_calobj,
+                                GError **error)
 {
 	/* ECalBackendKolab *self = NULL; */
 	/* ECalBackendKolabPrivate *priv = NULL; */
@@ -1559,13 +1562,13 @@ e_cal_backend_kolab_send_objects (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_get_attachment_uris (ECalBackendSync *backend,
-                                         EDataCal *cal,
-                                         GCancellable *cancellable,
-                                         const gchar *uid,
-                                         const gchar *rid,
-                                         GSList **attachments,
-                                         GError **error)
+cal_backend_kolab_get_attachment_uris (ECalBackendSync *backend,
+                                       EDataCal *cal,
+                                       GCancellable *cancellable,
+                                       const gchar *uid,
+                                       const gchar *rid,
+                                       GSList **attachments,
+                                       GError **error)
 {
 	/* ECalBackendKolab *self = NULL; */
 	/* ECalBackendKolabPrivate *priv = NULL; */
@@ -1585,13 +1588,13 @@ e_cal_backend_kolab_get_attachment_uris (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_discard_alarm (ECalBackendSync *backend,
-                                   EDataCal *cal,
-                                   GCancellable *cancellable,
-                                   const gchar *uid,
-                                   const gchar *rid,
-                                   const gchar *auid,
-                                   GError **error)
+cal_backend_kolab_discard_alarm (ECalBackendSync *backend,
+                                 EDataCal *cal,
+                                 GCancellable *cancellable,
+                                 const gchar *uid,
+                                 const gchar *rid,
+                                 const gchar *auid,
+                                 GError **error)
 {
 	/* ECalBackendKolab *self = NULL; */
 	/* ECalBackendKolabPrivate *priv = NULL; */
@@ -1611,12 +1614,12 @@ e_cal_backend_kolab_discard_alarm (ECalBackendSync *backend,
 }
 
 static void
-e_cal_backend_kolab_get_timezone (ECalBackendSync *backend,
-                                  EDataCal *cal,
-                                  GCancellable *cancellable,
-                                  const gchar *tzid,
-                                  gchar **tzobject,
-                                  GError **error)
+cal_backend_kolab_get_timezone (ECalBackendSync *backend,
+                                EDataCal *cal,
+                                GCancellable *cancellable,
+                                const gchar *tzid,
+                                gchar **tzobject,
+                                GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -1646,7 +1649,7 @@ e_cal_backend_kolab_get_timezone (ECalBackendSync *backend,
 }
 
 /**
- * e_cal_backend_kolab_add_timezone:
+ * cal_backend_kolab_add_timezone:
  * @backend: An ECalBackendSync object.
  * @cal: An EDataCal object.
  * @cancellable: A cancellation stack.
@@ -1656,11 +1659,11 @@ e_cal_backend_kolab_get_timezone (ECalBackendSync *backend,
  * Add a timezone object to the given backend.
  */
 static void
-e_cal_backend_kolab_add_timezone (ECalBackendSync *backend,
-                                  EDataCal *cal,
-                                  GCancellable *cancellable,
-                                  const gchar *tzobject,
-                                  GError **error)
+cal_backend_kolab_add_timezone (ECalBackendSync *backend,
+                                EDataCal *cal,
+                                GCancellable *cancellable,
+                                const gchar *tzobject,
+                                GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -1691,11 +1694,11 @@ e_cal_backend_kolab_add_timezone (ECalBackendSync *backend,
 		                            icalcomp);
 
 		if (! e_cal_backend_cache_put_timezone (priv->cal_cache, icaltz)) {
-			g_warning ("%s()[%u]: Putting timezone in cache failed.",
+			g_warning ("%s()[%u]: Putting timezone object into cache failed.",
 			           __func__, __LINE__);
 			icaltimezone_free (icaltz, 1);
-			/* TODO add a translatable string as custom message */
-			tmp_err = e_data_cal_create_error (OtherError, NULL);
+			tmp_err = e_data_cal_create_error (OtherError,
+			                                   _("Putting timezone object into cache failed."));
 			return;
 		}
 		icaltimezone_free (icaltz, 1);
@@ -1705,10 +1708,10 @@ e_cal_backend_kolab_add_timezone (ECalBackendSync *backend,
 #if 0  /* FIXME Delete this once kolab_mail_access_try_password_sync()
         *       works.  There may be code here that can be reused. */
 static void
-e_cal_backend_kolab_authenticate_user (ECalBackendSync *backend,
-                                       GCancellable *cancellable,
-                                       ECredentials *credentials,
-                                       GError **error)
+cal_backend_kolab_authenticate_user (ECalBackendSync *backend,
+                                     GCancellable *cancellable,
+                                     ECredentials *credentials,
+                                     GError **error)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -1782,15 +1785,15 @@ e_cal_backend_kolab_authenticate_user (ECalBackendSync *backend,
 #endif
 
 /**
- * e_cal_backend_kolab_start_view:
+ * cal_backend_kolab_start_view:
  * @backend: A calendar backend.
  * @view: The view to be started.
  *
  * Starts a new live query on the given backend.
  */
 static void
-e_cal_backend_kolab_start_view (ECalBackend *backend,
-                                EDataCalView *view)
+cal_backend_kolab_start_view (ECalBackend *backend,
+                              EDataCalView *view)
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
@@ -1895,8 +1898,8 @@ e_cal_backend_kolab_start_view (ECalBackend *backend,
 }
 
 static void
-e_cal_backend_kolab_stop_view (ECalBackend *backend,
-                               EDataCalView *view)
+cal_backend_kolab_stop_view (ECalBackend *backend,
+                             EDataCalView *view)
 {
 	/* ECalBackendKolab *self = NULL; */
 	/* ECalBackendKolabPrivate *priv = NULL; */
@@ -2012,29 +2015,29 @@ e_cal_backend_kolab_class_init (ECalBackendKolabClass *klass)
 	object_class->finalize = e_cal_backend_kolab_finalize;
 
 	/* Backend parent class methods methods not covered in the sync backend part */
-	backend_class->start_view = e_cal_backend_kolab_start_view;
-	backend_class->stop_view = e_cal_backend_kolab_stop_view;
+	backend_class->start_view = cal_backend_kolab_start_view;
+	backend_class->stop_view = cal_backend_kolab_stop_view;
 
 	/* Sync backend class functions */
-	sync_class->open_sync = e_cal_backend_kolab_open;
-	sync_class->remove_sync = e_cal_backend_kolab_remove;
-	sync_class->refresh_sync = e_cal_backend_kolab_refresh;
-	sync_class->get_backend_property_sync = e_cal_backend_kolab_get_backend_property;
+	sync_class->open_sync = cal_backend_kolab_open;
+	sync_class->remove_sync = cal_backend_kolab_remove;
+	sync_class->refresh_sync = cal_backend_kolab_refresh;
+	sync_class->get_backend_property_sync = cal_backend_kolab_get_backend_property;
 #if 0 /* probably not needed */
-	sync_class->set_backend_property_sync = e_cal_backend_kolab_set_backend_property;
+	sync_class->set_backend_property_sync = cal_backend_kolab_set_backend_property;
 #endif
-	sync_class->get_object_sync = e_cal_backend_kolab_get_object;
-	sync_class->get_object_list_sync = e_cal_backend_kolab_get_object_list;
-	sync_class->get_free_busy_sync = e_cal_backend_kolab_get_free_busy;
-	sync_class->create_objects_sync = e_cal_backend_kolab_create_objects;
-	sync_class->modify_objects_sync = e_cal_backend_kolab_modify_objects;
-	sync_class->remove_objects_sync = e_cal_backend_kolab_remove_objects;
-	sync_class->receive_objects_sync = e_cal_backend_kolab_receive_objects;
-	sync_class->send_objects_sync = e_cal_backend_kolab_send_objects;
-	sync_class->get_attachment_uris_sync = e_cal_backend_kolab_get_attachment_uris;
-	sync_class->discard_alarm_sync = e_cal_backend_kolab_discard_alarm;
-	sync_class->get_timezone_sync = e_cal_backend_kolab_get_timezone;
-	sync_class->add_timezone_sync = e_cal_backend_kolab_add_timezone;
+	sync_class->get_object_sync = cal_backend_kolab_get_object;
+	sync_class->get_object_list_sync = cal_backend_kolab_get_object_list;
+	sync_class->get_free_busy_sync = cal_backend_kolab_get_free_busy;
+	sync_class->create_objects_sync = cal_backend_kolab_create_objects;
+	sync_class->modify_objects_sync = cal_backend_kolab_modify_objects;
+	sync_class->remove_objects_sync = cal_backend_kolab_remove_objects;
+	sync_class->receive_objects_sync = cal_backend_kolab_receive_objects;
+	sync_class->send_objects_sync = cal_backend_kolab_send_objects;
+	sync_class->get_attachment_uris_sync = cal_backend_kolab_get_attachment_uris;
+	sync_class->discard_alarm_sync = cal_backend_kolab_discard_alarm;
+	sync_class->get_timezone_sync = cal_backend_kolab_get_timezone;
+	sync_class->add_timezone_sync = cal_backend_kolab_add_timezone;
 
 } /* e_cal_backend_kolab_class_init () */
 
