@@ -35,9 +35,9 @@
 /* internal statics */
 
 static KolabUtilHttpJob*
-kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
-                                         const gchar *path,
-                                         GError **error)
+util_calendar_create_http_request (KolabSettingsHandler *ksettings,
+                                   const gchar *path,
+                                   GError **error)
 {
 	CamelURL *url = NULL;
 	CamelKolabIMAPXSettings *settings;
@@ -67,12 +67,12 @@ kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
 	job->passwd = g_strdup (passwd); /* no longer carried by CamelURL */
 
 	return job;
-} /* kolab_util_calendar_create_http_request () */
+} /* util_calendar_create_http_request () */
 
 static KolabUtilHttpJob*
-kolab_util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
-                                        const gchar *sourcename,
-                                        GError **error)
+util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
+                                  const gchar *sourcename,
+                                  GError **error)
 {
 	CamelKolabIMAPXSettings *camel_settings;
 	CamelNetworkSettings *network_settings;
@@ -96,21 +96,21 @@ kolab_util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
 	path = g_strdup_printf ("/freebusy/trigger/%s/%s.pfb",
 	                        username, sourcename+source_offset);
 
-	job = kolab_util_calendar_create_http_request (ksettings,
-	                                               path,
-	                                               &tmp_err);
+	job = util_calendar_create_http_request (ksettings,
+	                                         path,
+	                                         &tmp_err);
 	g_free (path);
 	if (job == NULL) {
 		g_propagate_error (error, tmp_err);
 		return NULL;
 	}
 	return job;
-} /* kolab_util_calendar_create_pfb_trigger () */
+} /* util_calendar_create_pfb_trigger () */
 
 static KolabUtilHttpJob*
-kolab_util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
-                                        gchar *query,
-                                        GError **error)
+util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
+                                  gchar *query,
+                                  GError **error)
 {
 	KolabUtilHttpJob *job = NULL;
 	gchar *path = NULL;
@@ -122,9 +122,9 @@ kolab_util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
 
 	path = g_strdup_printf ("/freebusy/%s.ifb", query);
 
-	job = kolab_util_calendar_create_http_request (ksettings,
-	                                               path,
-	                                               &tmp_err);
+	job = util_calendar_create_http_request (ksettings,
+	                                         path,
+	                                         &tmp_err);
 	g_free (path);
 	if (job == NULL) {
 		g_propagate_error (error, tmp_err);
@@ -133,7 +133,7 @@ kolab_util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
 		return NULL;
 	}
 	return job;
-} /* kolab_util_calendar_create_xfb_request () */
+} /* util_calendar_create_xfb_request () */
 
 /*----------------------------------------------------------------------------*/
 /* public API */
@@ -202,9 +202,9 @@ kolab_util_calendar_toggle_pfb_trigger (KolabSettingsHandler *ksettings,
 	g_assert (sourcename != NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	job = kolab_util_calendar_create_pfb_trigger (ksettings,
-	                                              sourcename,
-	                                              &tmp_err);
+	job = util_calendar_create_pfb_trigger (ksettings,
+	                                        sourcename,
+	                                        &tmp_err);
 	if (job == NULL) {
 		g_propagate_error (error, tmp_err);
 		g_warning ("%s()[%u] error: could not create F/B toggle, giving up on %s.",
@@ -234,9 +234,9 @@ kolab_util_calendar_retrieve_xfb (KolabSettingsHandler *ksettings,
 	g_assert (query != NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	job = kolab_util_calendar_create_xfb_request (ksettings,
-	                                              (gchar *) query,
-	                                              &tmp_err);
+	job = util_calendar_create_xfb_request (ksettings,
+	                                        (gchar *) query,
+	                                        &tmp_err);
 	if (job == NULL) {
 		g_propagate_error (error, tmp_err);
 		g_warning ("%s()[%u] error creating job, giving up on %s.",
