@@ -34,6 +34,9 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include <shell/e-shell-view.h>
+#include <misc/e-alert-bar.h>
+
 #include <libekolab/kolab-data-folder-metadata.h>
 
 /*----------------------------------------------------------------------------*/
@@ -41,21 +44,27 @@
 typedef struct _KolabFolderMetaUIWidgets KolabFolderMetaUIWidgets;
 struct _KolabFolderMetaUIWidgets {
 	GtkWidget *container;
-	/* sub-widgets of container */
+	/* sub-widgets of container - folder type */
+	GtkWidget *frame_type_select;
 	GSList *radio_group;
 	GtkWidget *radio_btn_type_mail;
 	GtkWidget *radio_btn_type_calendar;
 	GtkWidget *radio_btn_type_memos;
 	GtkWidget *radio_btn_type_tasks;
 	GtkWidget *radio_btn_type_contacts;
+	/* sub-widgets of container - folder options */
+	GtkWidget *frame_options;
+	GtkWidget *chk_btn_show_all;
 };
 
 typedef struct _KolabFolderMetaUIData KolabFolderMetaUIData;
 struct _KolabFolderMetaUIData {
+	EShellView *shell_view;
+	EAlertBar *alert_bar;
 	KolabFolderMetaUIWidgets *widgets;
 	KolabDataFolderMetadata *metadata;
-	gchar *selected_folder;
-	gchar *selected_source;
+	gchar *foldername;
+	gchar *sourcename;
 };
 
 /*----------------------------------------------------------------------------*/
