@@ -34,6 +34,9 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include <shell/e-shell-view.h>
+#include <misc/e-alert-bar.h>
+
 #include <libekolab/kolab-data-folder-permissions.h>
 #include <libekolab/kolab-data-imap-account.h>
 
@@ -45,6 +48,8 @@ typedef struct _KolabFolderPermUIWidgets KolabFolderPermUIWidgets;
 struct _KolabFolderPermUIWidgets {
 	GtkWidget *container;
 	/* sub-widgets of container */
+	GtkWidget *myrights;
+	GtkWidget *myrights_lbl;
 	GtkWidget *treeview;
 	GtkWidget *btn_add;
 	GtkWidget *btn_edit;
@@ -63,10 +68,12 @@ struct _KolabFolderPermUIWidgets {
 
 typedef struct _KolabFolderPermUIData KolabFolderPermUIData;
 struct _KolabFolderPermUIData {
+	EShellView *shell_view;
+	EAlertBar *alert_bar;
 	KolabFolderPermUIWidgets *widgets;
 	KolabDataFolderPermissions *permissions;
-	gchar *selected_folder;
-	gchar *selected_source;
+	gchar *foldername;
+	gchar *sourcename;
 };
 
 /*----------------------------------------------------------------------------*/
