@@ -168,6 +168,11 @@ GList*
 kolab_mail_access_query_sources (KolabMailAccess *self,
                                  GError **err);
 
+GList*
+kolab_mail_access_query_folder_info_online (KolabMailAccess *self,
+                                            GCancellable *cancellable,
+                                            GError **err);
+
 gboolean
 kolab_mail_access_create_source (KolabMailAccess *self,
                                  const gchar *sourcename,
