@@ -174,10 +174,10 @@ kolab_mail_imap_client_class_init (KolabMailImapClientClass *klass)
 /* camel helpers */
 
 static CamelFolder*
-kolab_mail_imap_client_camel_get_folder (KolabMailImapClient *self,
-                                         const gchar *foldername,
-                                         GCancellable *cancellable,
-                                         GError **err)
+mail_imap_client_camel_get_folder (KolabMailImapClient *self,
+                                   const gchar *foldername,
+                                   GCancellable *cancellable,
+                                   GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
 	CamelFolder *folder = NULL;
@@ -234,12 +234,12 @@ kolab_mail_imap_client_camel_get_folder (KolabMailImapClient *self,
 }
 
 static GHashTable*
-kolab_mail_imap_client_camel_gen_summaries (KolabMailImapClient *self,
-                                            const gchar *foldername,
-                                            KolabFolderTypeID foldertype,
-                                            KolabFolderContextID foldercontext,
-                                            GCancellable *cancellable,
-                                            GError **err)
+mail_imap_client_camel_gen_summaries (KolabMailImapClient *self,
+                                      const gchar *foldername,
+                                      KolabFolderTypeID foldertype,
+                                      KolabFolderContextID foldercontext,
+                                      GCancellable *cancellable,
+                                      GError **err)
 {
 	/* KolabMailImapClientPrivate *priv = NULL; */
 	CamelFolder *folder = NULL;
@@ -259,10 +259,10 @@ kolab_mail_imap_client_camel_gen_summaries (KolabMailImapClient *self,
 	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
 
 	/* priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self); */
-	folder =  kolab_mail_imap_client_camel_get_folder (self,
-	                                                   foldername,
-	                                                   cancellable,
-	                                                   &tmp_err);
+	folder =  mail_imap_client_camel_get_folder (self,
+	                                             foldername,
+	                                             cancellable,
+	                                             &tmp_err);
 	if (folder == NULL) {
 		g_propagate_error (err, tmp_err);
 		return NULL;
@@ -354,12 +354,12 @@ kolab_mail_imap_client_camel_gen_summaries (KolabMailImapClient *self,
 }
 
 static CamelMimeMessage*
-kolab_mail_imap_client_camel_get_msg_imap_uid (KolabMailImapClient *self,
-                                               const gchar *foldername,
-                                               const gchar *imap_uid,
-                                               const gchar *kolab_uid,
-                                               GCancellable *cancellable,
-                                               GError **err)
+mail_imap_client_camel_get_msg_imap_uid (KolabMailImapClient *self,
+                                         const gchar *foldername,
+                                         const gchar *imap_uid,
+                                         const gchar *kolab_uid,
+                                         GCancellable *cancellable,
+                                         GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
 	CamelFolder *folder = NULL;
@@ -378,10 +378,10 @@ kolab_mail_imap_client_camel_get_msg_imap_uid (KolabMailImapClient *self,
 
 	g_assert (priv->is_up == TRUE);
 
-	folder = kolab_mail_imap_client_camel_get_folder (self,
-	                                                  foldername,
-	                                                  cancellable,
-	                                                  &tmp_err);
+	folder = mail_imap_client_camel_get_folder (self,
+	                                            foldername,
+	                                            cancellable,
+	                                            &tmp_err);
 	if (folder == NULL) {
 		g_propagate_error (err, tmp_err);
 		return NULL;
@@ -449,11 +449,11 @@ kolab_mail_imap_client_camel_get_msg_imap_uid (KolabMailImapClient *self,
 }
 
 static CamelMimeMessage*
-kolab_mail_imap_client_camel_get_msg_kolab_uid (KolabMailImapClient *self,
-                                                const gchar *foldername,
-                                                const gchar *kolab_uid,
-                                                GCancellable *cancellable,
-                                                GError **err)
+mail_imap_client_camel_get_msg_kolab_uid (KolabMailImapClient *self,
+                                          const gchar *foldername,
+                                          const gchar *kolab_uid,
+                                          GCancellable *cancellable,
+                                          GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
 	CamelFolder *folder = NULL;
@@ -472,10 +472,10 @@ kolab_mail_imap_client_camel_get_msg_kolab_uid (KolabMailImapClient *self,
 
 	g_assert (priv->is_up == TRUE);
 
-	folder = kolab_mail_imap_client_camel_get_folder (self,
-	                                                  foldername,
-	                                                  cancellable,
-	                                                  &tmp_err);
+	folder = mail_imap_client_camel_get_folder (self,
+	                                            foldername,
+	                                            cancellable,
+	                                            &tmp_err);
 	if (folder ==  NULL) {
 		g_propagate_error (err, tmp_err);
 		return NULL;
@@ -505,12 +505,12 @@ kolab_mail_imap_client_camel_get_msg_kolab_uid (KolabMailImapClient *self,
 			continue;
 		}
 
-		message = kolab_mail_imap_client_camel_get_msg_imap_uid (self,
-		                                                         foldername,
-		                                                         imap_uid,
-		                                                         NULL,
-		                                                         cancellable,
-		                                                         &tmp_err);
+		message = mail_imap_client_camel_get_msg_imap_uid (self,
+		                                                   foldername,
+		                                                   imap_uid,
+		                                                   NULL,
+		                                                   cancellable,
+		                                                   &tmp_err);
 		if (tmp_err != NULL) {
 			if (message != NULL) {
 				g_object_unref (message);
@@ -550,10 +550,10 @@ kolab_mail_imap_client_camel_get_msg_kolab_uid (KolabMailImapClient *self,
 /* folder helpers */
 
 static gboolean
-kolab_mail_imap_client_update_folder (KolabMailImapClient *self,
-                                      const gchar *foldername,
-                                      GCancellable *cancellable,
-                                      GError **err)
+mail_imap_client_update_folder (KolabMailImapClient *self,
+                                const gchar *foldername,
+                                GCancellable *cancellable,
+                                GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
 	CamelFolder *folder = NULL;
@@ -566,10 +566,10 @@ kolab_mail_imap_client_update_folder (KolabMailImapClient *self,
 
 	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
 
-	folder = kolab_mail_imap_client_camel_get_folder (self,
-	                                                  foldername,
-	                                                  cancellable,
-	                                                  &tmp_err);
+	folder = mail_imap_client_camel_get_folder (self,
+	                                            foldername,
+	                                            cancellable,
+	                                            &tmp_err);
 	if (folder == NULL) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -628,6 +628,56 @@ kolab_mail_imap_client_update_folder (KolabMailImapClient *self,
 	return TRUE;
 }
 
+static GList*
+mail_imap_client_query_foldernames (KolabMailImapClient *self,
+                                    GCancellable *cancellable,
+                                    gboolean do_updatedb,
+                                    GError **err)
+{
+	KolabMailImapClientPrivate *priv = NULL;
+	CamelFolderInfo *fi = NULL;
+	GList *folder_list = NULL;
+	CamelStoreGetFolderInfoFlags flags = 0;
+	GError *tmp_err = NULL;
+
+	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
+
+	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
+
+	g_assert (priv->is_up == TRUE);
+
+	flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL;
+	if (do_updatedb) {
+		/* persistently stores folder info */
+		fi = camel_store_get_folder_info_sync (CAMEL_STORE (priv->store),
+		                                       NULL,
+		                                       flags,
+		                                       cancellable,
+		                                       &tmp_err);
+	} else {
+		/* does not store folder info persistently */
+		fi = camel_kolab_imapx_store_get_folder_info_online (priv->store,
+		                                                     NULL,
+		                                                     flags,
+		                                                     cancellable,
+		                                                     &tmp_err);
+	}
+	if (tmp_err != NULL) {
+		g_propagate_error (err, tmp_err);
+		return NULL;
+	}
+
+	if (fi == NULL)
+		return NULL;
+
+	camel_store_free_folder_info (CAMEL_STORE (priv->store), fi);
+
+	folder_list = camel_kolab_imapx_store_resect_folder_list (priv->store);
+	return folder_list;
+}
+
 /*----------------------------------------------------------------------------*/
 /* object config/status */
 
@@ -710,7 +760,7 @@ kolab_mail_imap_client_configure (KolabMailImapClient *self,
 }
 
 static void
-kolab_mail_imap_client_configure_store_settings (KolabMailImapClient *self)
+mail_imap_client_configure_store_settings (KolabMailImapClient *self)
 {
 	KolabMailImapClientPrivate *priv = NULL;
 	CamelService *service = NULL;
@@ -794,13 +844,13 @@ kolab_mail_imap_client_bringup (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CAMEL,
-		             "Could not set PIM folder context %i for this backend",
+		             _("Could not set PIM folder context %i for this backend"),
 		             priv->context);
 		return FALSE;
 	}
 
 	/* configure the service with settings from KolabSettingsHandler */
-	kolab_mail_imap_client_configure_store_settings (self);
+	mail_imap_client_configure_store_settings (self);
 
 	/* set offline state */
 	ok = camel_offline_store_set_online_sync (CAMEL_OFFLINE_STORE (priv->store),
@@ -1017,43 +1067,23 @@ kolab_mail_imap_client_query_foldernames (KolabMailImapClient *self,
                                           GCancellable *cancellable,
                                           GError **err)
 {
-	KolabMailImapClientPrivate *priv = NULL;
-	CamelFolderInfo *fi = NULL;
 	GList *folder_list = NULL;
-	CamelStoreGetFolderInfoFlags flags = 0;
-	GError *tmp_err = NULL;
 
 	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
 
-	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
-
-	g_assert (priv->is_up == TRUE);
-
-	flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL;
-	fi = camel_store_get_folder_info_sync (CAMEL_STORE (priv->store),
-	                                       NULL,
-	                                       flags,
-	                                       cancellable,
-	                                       &tmp_err);
-	if (tmp_err != NULL) {
-		g_propagate_error (err, tmp_err);
-		return NULL;
-	}
-
-	if (fi == NULL)
-		return NULL;
-
-	camel_store_free_folder_info (CAMEL_STORE (priv->store), fi);
-
-	folder_list = camel_kolab_imapx_store_resect_folder_list (priv->store);
+	folder_list = mail_imap_client_query_foldernames (self,
+	                                                  cancellable,
+	                                                  TRUE, /* update SQlite DBs */
+	                                                  err);
 	return folder_list;
 }
 
 KolabFolderTypeID
 kolab_mail_imap_client_get_folder_type (KolabMailImapClient *self,
                                         const gchar *foldername,
+                                        gboolean do_updatedb,
                                         GCancellable *cancellable,
                                         GError **err)
 {
@@ -1070,6 +1100,7 @@ kolab_mail_imap_client_get_folder_type (KolabMailImapClient *self,
 
 	foldertype = camel_kolab_imapx_store_get_folder_type (priv->store,
 	                                                      foldername,
+	                                                      do_updatedb,
 	                                                      cancellable,
 	                                                      &tmp_err);
 	if (tmp_err != NULL) {
@@ -1088,11 +1119,75 @@ kolab_mail_imap_client_get_folder_type (KolabMailImapClient *self,
 	return foldertype;
 }
 
+GList*
+kolab_mail_imap_client_query_folder_info_online (KolabMailImapClient *self,
+                                                 GCancellable *cancellable,
+                                                 GError **err)
+{
+	KolabMailImapClientPrivate *priv = NULL;
+	GList *folder_names = NULL;
+	GList *folder_names_ptr = NULL;
+	GList *folder_desc = NULL;
+	GError *tmp_err = NULL;
+
+	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, KOLAB_FOLDER_TYPE_INVAL);
+
+	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
+
+	if (! camel_session_get_online (CAMEL_SESSION (priv->session))) {
+		g_set_error (err,
+		             KOLAB_CAMEL_ERROR,
+		             KOLAB_CAMEL_ERROR_GENERIC,
+		             _("You must be working online to complete this operation"));
+		return NULL;
+	}
+
+	folder_names = mail_imap_client_query_foldernames (self,
+	                                                   cancellable,
+	                                                   FALSE, /* do not update DBs */
+	                                                   &tmp_err);
+	if (tmp_err != NULL) {
+		g_propagate_error (err, tmp_err);
+		return NULL;
+	}
+
+	folder_names_ptr = folder_names;
+	while (folder_names_ptr != NULL) {
+		gchar *foldername = (gchar*) folder_names_ptr->data;
+		KolabFolderDescriptor *desc = NULL;
+		KolabFolderTypeID type_id = KOLAB_FOLDER_TYPE_INVAL;
+		type_id = kolab_mail_imap_client_get_folder_type (self,
+		                                                  foldername,
+		                                                  FALSE, /* do not update DBs */
+		                                                  cancellable,
+		                                                  &tmp_err);
+		if (tmp_err != NULL)
+			break;
+
+		desc = kolab_util_folder_descriptor_new (foldername,
+		                                         type_id);
+		folder_desc = g_list_prepend (folder_desc, desc);
+
+		folder_names_ptr = g_list_next (folder_names_ptr);
+	}
+
+	if (tmp_err != NULL) {
+		g_propagate_error (err, tmp_err);
+		kolab_util_glib_glist_free (folder_names);
+		kolab_util_folder_descriptor_glist_free (folder_desc);
+		return NULL;
+	}
+
+	return folder_desc;
+}
+
 static guint64
-kolab_mail_imap_client_get_folder_uidvalidity (KolabMailImapClient *self,
-                                               const gchar *foldername,
-                                               GCancellable *cancellable,
-                                               GError **err)
+mail_imap_client_get_folder_uidvalidity (KolabMailImapClient *self,
+                                         const gchar *foldername,
+                                         GCancellable *cancellable,
+                                         GError **err)
 {
 	/* KolabMailImapClientPrivate *priv = NULL; */
 	CamelFolder *folder = NULL;
@@ -1106,10 +1201,10 @@ kolab_mail_imap_client_get_folder_uidvalidity (KolabMailImapClient *self,
 
 	/* priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self); */
 
-	folder = kolab_mail_imap_client_camel_get_folder (self,
-	                                                  foldername,
-	                                                  cancellable,
-	                                                  &tmp_err);
+	folder = mail_imap_client_camel_get_folder (self,
+	                                            foldername,
+	                                            cancellable,
+	                                            &tmp_err);
 	if (folder == NULL) {
 		g_propagate_error (err, tmp_err);
 		return 0;
@@ -1153,6 +1248,7 @@ kolab_mail_imap_client_query_folder_summary (KolabMailImapClient *self,
 
 	foldertype = kolab_mail_imap_client_get_folder_type (self,
 	                                                     foldername,
+	                                                     TRUE, /* update DBs */
 	                                                     cancellable,
 	                                                     &tmp_err);
 	if (tmp_err != NULL) {
@@ -1160,10 +1256,10 @@ kolab_mail_imap_client_query_folder_summary (KolabMailImapClient *self,
 		return NULL;
 	}
 
-	uidvalidity = kolab_mail_imap_client_get_folder_uidvalidity (self,
-	                                                             foldername,
-	                                                             cancellable,
-	                                                             &tmp_err);
+	uidvalidity = mail_imap_client_get_folder_uidvalidity (self,
+	                                                       foldername,
+	                                                       cancellable,
+	                                                       &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return NULL;
@@ -1311,6 +1407,7 @@ kolab_mail_imap_client_query_summaries (KolabMailImapClient *self,
 	/* get folder type and context */
 	foldertype = kolab_mail_imap_client_get_folder_type (self,
 	                                                     foldername,
+	                                                     TRUE, /* update DBs */
 	                                                     cancellable,
 	                                                     &tmp_err);
 	if (foldertype == KOLAB_FOLDER_TYPE_INVAL) {
@@ -1329,10 +1426,10 @@ kolab_mail_imap_client_query_summaries (KolabMailImapClient *self,
 
 	/* update the CamelFolder */
 	if (update) {
-		ok = kolab_mail_imap_client_update_folder (self,
-		                                           foldername,
-		                                           cancellable,
-		                                           &tmp_err);
+		ok = mail_imap_client_update_folder (self,
+		                                     foldername,
+		                                     cancellable,
+		                                     &tmp_err);
 		if (! ok) {
 			g_propagate_error (err, tmp_err);
 			return NULL;
@@ -1340,12 +1437,12 @@ kolab_mail_imap_client_query_summaries (KolabMailImapClient *self,
 	}
 
 	/* generate summaries table. may be NULL */
-	summaries = kolab_mail_imap_client_camel_gen_summaries (self,
-	                                                        foldername,
-	                                                        foldertype,
-	                                                        foldercontext,
-	                                                        cancellable,
-	                                                        &tmp_err);
+	summaries = mail_imap_client_camel_gen_summaries (self,
+	                                                  foldername,
+	                                                  foldertype,
+	                                                  foldercontext,
+	                                                  cancellable,
+	                                                  &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return NULL;
@@ -1418,19 +1515,19 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 
 	/* update the CamelFolder */
 	if (update) {
-		ok = kolab_mail_imap_client_update_folder (self,
-		                                           foldername,
-		                                           cancellable,
-		                                           &tmp_err);
+		ok = mail_imap_client_update_folder (self,
+		                                     foldername,
+		                                     cancellable,
+		                                     &tmp_err);
 		if (! ok)
 			goto cleanup;
 	}
 
 	/* normal store operation (handle_foldername may be unset) */
-	folder = kolab_mail_imap_client_camel_get_folder (self,
-	                                                  foldername,
-	                                                  cancellable,
-	                                                  &tmp_err);
+	folder = mail_imap_client_camel_get_folder (self,
+	                                            foldername,
+	                                            cancellable,
+	                                            &tmp_err);
 	if (tmp_err != NULL)
 		goto cleanup;
 
@@ -1451,12 +1548,12 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 	kolab_uid = kolab_mail_handle_get_uid (kmailhandle);
 
 	if (imap_uid != NULL) {
-		orig_message = kolab_mail_imap_client_camel_get_msg_imap_uid (self,
-		                                                              foldername,
-		                                                              imap_uid,
-		                                                              kolab_uid,
-		                                                              cancellable,
-		                                                              &tmp_err);
+		orig_message = mail_imap_client_camel_get_msg_imap_uid (self,
+		                                                        foldername,
+		                                                        imap_uid,
+		                                                        kolab_uid,
+		                                                        cancellable,
+		                                                        &tmp_err);
 		if (tmp_err != NULL) {
 			g_warning ("%s: %s", __func__, tmp_err->message);
 			g_error_free (tmp_err);
@@ -1466,11 +1563,11 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 
 	/* if no luck with imap uid, we'll need to search messages for kolab uid */
 	if (orig_message == NULL) {
-		orig_message = kolab_mail_imap_client_camel_get_msg_kolab_uid (self,
-		                                                               foldername,
-		                                                               kolab_uid,
-		                                                               cancellable,
-		                                                               &tmp_err);
+		orig_message = mail_imap_client_camel_get_msg_kolab_uid (self,
+		                                                         foldername,
+		                                                         kolab_uid,
+		                                                         cancellable,
+		                                                         &tmp_err);
 		if (tmp_err != NULL) {
 			g_warning ("%s: %s", __func__, tmp_err->message);
 			g_error_free (tmp_err);
@@ -1535,11 +1632,11 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 	 *         in the IMAPX offline store, but the IMAP UID of the freshly stored message
 	 *         is exactly what IMAPX does not provide us with here (see above)
 	 */
-	stored_message = kolab_mail_imap_client_camel_get_msg_kolab_uid (self,
-	                                                                 foldername,
-	                                                                 kolab_uid,
-	                                                                 cancellable,
-	                                                                 &tmp_err);
+	stored_message = mail_imap_client_camel_get_msg_kolab_uid (self,
+	                                                           foldername,
+	                                                           kolab_uid,
+	                                                           cancellable,
+	                                                           &tmp_err);
 	if (tmp_err != NULL)
 		goto cleanup;
 
@@ -1684,6 +1781,7 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 	/* folder type/context checking */
 	folder_type = kolab_mail_imap_client_get_folder_type (self,
 	                                                      foldername,
+	                                                      TRUE, /* update DBs */
 	                                                      cancellable,
 	                                                      &tmp_err);
 	if (tmp_err != NULL) {
@@ -1710,10 +1808,10 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 
 	/* update the CamelFolder */
 	if (update) {
-		ok = kolab_mail_imap_client_update_folder (self,
-		                                           foldername,
-		                                           cancellable,
-		                                           &tmp_err);
+		ok = mail_imap_client_update_folder (self,
+		                                     foldername,
+		                                     cancellable,
+		                                     &tmp_err);
 		if (! ok) {
 			g_propagate_error (err, tmp_err);
 			return FALSE;
@@ -1725,12 +1823,12 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 	                                              KOLAB_MAIL_SUMMARY_CHAR_FIELD_IMAP_UID);
 
 	if (imap_uid != NULL) {
-		camel_message = kolab_mail_imap_client_camel_get_msg_imap_uid (self,
-		                                                               foldername,
-		                                                               imap_uid,
-		                                                               kolab_uid,
-		                                                               cancellable,
-		                                                               &tmp_err);
+		camel_message = mail_imap_client_camel_get_msg_imap_uid (self,
+		                                                         foldername,
+		                                                         imap_uid,
+		                                                         kolab_uid,
+		                                                         cancellable,
+		                                                         &tmp_err);
 		if (tmp_err != NULL) {
 			g_warning ("%s: %s", __func__, tmp_err->message);
 			g_error_free (tmp_err);
@@ -1740,11 +1838,11 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 
 	/* if no luck with imap uid, we'll need to search messages for kolab uid */
 	if (camel_message == NULL) {
-		camel_message = kolab_mail_imap_client_camel_get_msg_kolab_uid (self,
-		                                                                foldername,
-		                                                                kolab_uid,
-		                                                                cancellable,
-		                                                                &tmp_err);
+		camel_message = mail_imap_client_camel_get_msg_kolab_uid (self,
+		                                                          foldername,
+		                                                          kolab_uid,
+		                                                          cancellable,
+		                                                          &tmp_err);
 		if (tmp_err != NULL) {
 			g_propagate_error (err, tmp_err);
 			return FALSE;
@@ -1838,10 +1936,10 @@ kolab_mail_imap_client_delete (KolabMailImapClient *self,
 
 	/* update the CamelFolder */
 	if (update) {
-		ok = kolab_mail_imap_client_update_folder (self,
-		                                           foldername,
-		                                           cancellable,
-		                                           &tmp_err);
+		ok = mail_imap_client_update_folder (self,
+		                                     foldername,
+		                                     cancellable,
+		                                     &tmp_err);
 		if (! ok) {
 			g_propagate_error (err, tmp_err);
 			return FALSE;
@@ -1849,10 +1947,10 @@ kolab_mail_imap_client_delete (KolabMailImapClient *self,
 	}
 
 	/* get the CamelFolder */
-	folder = kolab_mail_imap_client_camel_get_folder (self,
-	                                                  foldername,
-	                                                  cancellable,
-	                                                  &tmp_err);
+	folder = mail_imap_client_camel_get_folder (self,
+	                                            foldername,
+	                                            cancellable,
+	                                            &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -1873,12 +1971,12 @@ kolab_mail_imap_client_delete (KolabMailImapClient *self,
 	                                                        KOLAB_MAIL_SUMMARY_CHAR_FIELD_IMAP_UID));
 
 	if (imap_uid != NULL) {
-		camel_message = kolab_mail_imap_client_camel_get_msg_imap_uid (self,
-		                                                               foldername,
-		                                                               imap_uid,
-		                                                               kolab_uid,
-		                                                               cancellable,
-		                                                               &tmp_err);
+		camel_message = mail_imap_client_camel_get_msg_imap_uid (self,
+		                                                         foldername,
+		                                                         imap_uid,
+		                                                         kolab_uid,
+		                                                         cancellable,
+		                                                         &tmp_err);
 		if (tmp_err != NULL) {
 			g_warning ("%s: %s", __func__, tmp_err->message);
 			g_error_free (tmp_err);
@@ -1892,11 +1990,11 @@ kolab_mail_imap_client_delete (KolabMailImapClient *self,
 
 	/* if no luck with imap uid, we'll need to search messages for kolab uid */
 	if (camel_message == NULL) {
-		camel_message = kolab_mail_imap_client_camel_get_msg_kolab_uid (self,
-		                                                                foldername,
-		                                                                kolab_uid,
-		                                                                cancellable,
-		                                                                &tmp_err);
+		camel_message = mail_imap_client_camel_get_msg_kolab_uid (self,
+		                                                          foldername,
+		                                                          kolab_uid,
+		                                                          cancellable,
+		                                                          &tmp_err);
 		if (tmp_err != NULL) {
 			g_warning ("%s: %s", __func__, tmp_err->message);
 			g_error_free (tmp_err);
