@@ -157,14 +157,14 @@ kolab_mail_synchronizer_class_init (KolabMailSynchronizerClass *klass)
 }
 
 /*----------------------------------------------------------------------------*/
-/* locals */
+/* local statics */
 
 static KolabFolderTypeID
-kolab_mail_synchronizer_get_foldertype (KolabMailSynchronizer *self,
-                                        const gchar *info_fn,
-                                        const gchar *imap_fn,
-                                        GCancellable *cancellable,
-                                        GError **err)
+mail_synchronizer_get_foldertype (KolabMailSynchronizer *self,
+                                  const gchar *info_fn,
+                                  const gchar *imap_fn,
+                                  GCancellable *cancellable,
+                                  GError **err)
 
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
@@ -264,10 +264,10 @@ kolab_mail_synchronizer_get_foldertype (KolabMailSynchronizer *self,
 }
 
 static guint64
-kolab_mail_synchronizer_get_uidvalidity (KolabMailSynchronizer *self,
-                                         const gchar *info_fn,
-                                         const gchar *imap_fn,
-                                         GError **err)
+mail_synchronizer_get_uidvalidity (KolabMailSynchronizer *self,
+                                   const gchar *info_fn,
+                                   const gchar *imap_fn,
+                                   GError **err)
 
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
@@ -347,8 +347,8 @@ kolab_mail_synchronizer_get_uidvalidity (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_folders_uidvalidity_changed (KolabMailSynchronizer *self,
-                                                     KolabFolderSummary *summary)
+mail_synchronizer_folders_uidvalidity_changed (KolabMailSynchronizer *self,
+                                               KolabFolderSummary *summary)
 {
 	KolabObjectCacheStatus status = KOLAB_OBJECT_CACHE_STATUS_INVAL;
 
@@ -364,8 +364,8 @@ kolab_mail_synchronizer_folders_uidvalidity_changed (KolabMailSynchronizer *self
 }
 
 static void
-kolab_mail_synchronizer_folders_clear_changed (KolabMailSynchronizer *self,
-                                               KolabFolderSummary *summary)
+mail_synchronizer_folders_clear_changed (KolabMailSynchronizer *self,
+                                         KolabFolderSummary *summary)
 {
 	KolabObjectCacheStatus status = KOLAB_OBJECT_CACHE_STATUS_NONE;
 	guint64 uidvalidity = 0;
@@ -389,13 +389,13 @@ kolab_mail_synchronizer_folders_clear_changed (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_folders_update_summary (KolabMailSynchronizer *self,
-                                                KolabMailAccessOpmodeID opmode,
-                                                const gchar *info_fn,
-                                                const gchar *imap_fn,
-                                                const gchar *side_fn,
-                                                GCancellable *cancellable,
-                                                GError **err)
+mail_synchronizer_folders_update_summary (KolabMailSynchronizer *self,
+                                          KolabMailAccessOpmodeID opmode,
+                                          const gchar *info_fn,
+                                          const gchar *imap_fn,
+                                          const gchar *side_fn,
+                                          GCancellable *cancellable,
+                                          GError **err)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	KolabFolderSummary *summary = NULL;
@@ -475,11 +475,11 @@ kolab_mail_synchronizer_folders_update_summary (KolabMailSynchronizer *self,
 		g_assert_not_reached ();
 
 	/* folder type and context */
-	folder_type = kolab_mail_synchronizer_get_foldertype (self,
-	                                                      info_fn,
-	                                                      imap_fn,
-	                                                      cancellable,
-	                                                      &tmp_err);
+	folder_type = mail_synchronizer_get_foldertype (self,
+	                                                info_fn,
+	                                                imap_fn,
+	                                                cancellable,
+	                                                &tmp_err);
 	if (folder_type == KOLAB_FOLDER_TYPE_INVAL) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -496,10 +496,10 @@ kolab_mail_synchronizer_folders_update_summary (KolabMailSynchronizer *self,
 
 	/* folder uidvalidity change (only in online mode) */
 	if (opmode > KOLAB_MAIL_ACCESS_OPMODE_OFFLINE) {
-		uidval_srv = kolab_mail_synchronizer_get_uidvalidity (self,
-		                                                      info_fn,
-		                                                      imap_fn,
-		                                                      &tmp_err);
+		uidval_srv = mail_synchronizer_get_uidvalidity (self,
+		                                                info_fn,
+		                                                imap_fn,
+		                                                &tmp_err);
 		if (tmp_err != NULL) {
 			g_propagate_error (err, tmp_err);
 			return FALSE;
@@ -569,14 +569,14 @@ kolab_mail_synchronizer_folders_update_summary (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_folders_update_walk (KolabMailSynchronizer *self,
-                                             KolabMailAccessOpmodeID opmode,
-                                             KolabMailSynchronizerFolderWalkID walk_id,
-                                             GList *folders_lst,
-                                             GHashTable *imap_folders_tbl,
-                                             GHashTable *side_folders_tbl,
-                                             GCancellable *cancellable,
-                                             GError **err)
+mail_synchronizer_folders_update_walk (KolabMailSynchronizer *self,
+                                       KolabMailAccessOpmodeID opmode,
+                                       KolabMailSynchronizerFolderWalkID walk_id,
+                                       GList *folders_lst,
+                                       GHashTable *imap_folders_tbl,
+                                       GHashTable *side_folders_tbl,
+                                       GCancellable *cancellable,
+                                       GError **err)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	GList *lst_ptr = NULL;
@@ -631,13 +631,13 @@ kolab_mail_synchronizer_folders_update_walk (KolabMailSynchronizer *self,
 			g_assert_not_reached ();
 		}
 
-		ok = kolab_mail_synchronizer_folders_update_summary (self,
-		                                                     opmode,
-		                                                     info_fn,
-		                                                     imap_fn,
-		                                                     side_fn,
-		                                                     cancellable,
-		                                                     &tmp_err);
+		ok = mail_synchronizer_folders_update_summary (self,
+		                                               opmode,
+		                                               info_fn,
+		                                               imap_fn,
+		                                               side_fn,
+		                                               cancellable,
+		                                               &tmp_err);
 		if (! ok) {
 			g_propagate_error (err, tmp_err);
 			return FALSE;
@@ -667,10 +667,10 @@ kolab_mail_synchronizer_folders_update_walk (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_folders_update_infodb (KolabMailSynchronizer *self,
-                                               KolabMailAccessOpmodeID opmode,
-                                               GCancellable *cancellable,
-                                               GError **err)
+mail_synchronizer_folders_update_infodb (KolabMailSynchronizer *self,
+                                         KolabMailAccessOpmodeID opmode,
+                                         GCancellable *cancellable,
+                                         GError **err)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	GList *info_folders_lst = NULL;
@@ -713,14 +713,14 @@ kolab_mail_synchronizer_folders_update_infodb (KolabMailSynchronizer *self,
 		goto skip;
 
 	/* walk through InfoDb folders list */
-	ok = kolab_mail_synchronizer_folders_update_walk (self,
-	                                                  opmode,
-	                                                  KOLAB_MAIL_SYNCHRONIZER_FOLDER_WALK_INFO,
-	                                                  info_folders_lst,
-	                                                  imap_folders_tbl,
-	                                                  side_folders_tbl,
-	                                                  cancellable,
-	                                                  &tmp_err);
+	ok = mail_synchronizer_folders_update_walk (self,
+	                                            opmode,
+	                                            KOLAB_MAIL_SYNCHRONIZER_FOLDER_WALK_INFO,
+	                                            info_folders_lst,
+	                                            imap_folders_tbl,
+	                                            side_folders_tbl,
+	                                            cancellable,
+	                                            &tmp_err);
 	kolab_util_glib_glist_free (info_folders_lst);
 	info_folders_lst = NULL;
 	if (! ok)
@@ -729,14 +729,14 @@ kolab_mail_synchronizer_folders_update_infodb (KolabMailSynchronizer *self,
 	/* walk through remaining ImapClient folders list */
 	if (imap_folders_tbl != NULL) {
 		tmp_lst = g_hash_table_get_keys (imap_folders_tbl);
-		ok = kolab_mail_synchronizer_folders_update_walk (self,
-		                                                  opmode,
-		                                                  KOLAB_MAIL_SYNCHRONIZER_FOLDER_WALK_IMAP,
-		                                                  tmp_lst,
-		                                                  imap_folders_tbl,
-		                                                  side_folders_tbl,
-		                                                  cancellable,
-		                                                  &tmp_err);
+		ok = mail_synchronizer_folders_update_walk (self,
+		                                            opmode,
+		                                            KOLAB_MAIL_SYNCHRONIZER_FOLDER_WALK_IMAP,
+		                                            tmp_lst,
+		                                            imap_folders_tbl,
+		                                            side_folders_tbl,
+		                                            cancellable,
+		                                            &tmp_err);
 		g_list_free (tmp_lst);
 		tmp_lst = NULL;
 		if (! ok)
@@ -746,14 +746,14 @@ kolab_mail_synchronizer_folders_update_infodb (KolabMailSynchronizer *self,
 	/* walk through remaining SideCache folders list */
 	if (side_folders_tbl != NULL) {
 		tmp_lst = g_hash_table_get_keys (side_folders_tbl);
-		ok = kolab_mail_synchronizer_folders_update_walk (self,
-		                                                  opmode,
-		                                                  KOLAB_MAIL_SYNCHRONIZER_FOLDER_WALK_SIDE,
-		                                                  tmp_lst,
-		                                                  imap_folders_tbl,
-		                                                  side_folders_tbl,
-		                                                  cancellable,
-		                                                  &tmp_err);
+		ok = mail_synchronizer_folders_update_walk (self,
+		                                            opmode,
+		                                            KOLAB_MAIL_SYNCHRONIZER_FOLDER_WALK_SIDE,
+		                                            tmp_lst,
+		                                            imap_folders_tbl,
+		                                            side_folders_tbl,
+		                                            cancellable,
+		                                            &tmp_err);
 		g_list_free (tmp_lst);
 		tmp_lst = NULL;
 		if (! ok)
@@ -775,10 +775,10 @@ kolab_mail_synchronizer_folders_update_infodb (KolabMailSynchronizer *self,
 }
 
 static GList*
-kolab_mail_synchronizer_uid_combine_all (KolabMailSynchronizer *self,
-                                         const gchar *foldername,
-                                         GHashTable *imap_summaries_tbl,
-                                         GError **err)
+mail_synchronizer_uid_combine_all (KolabMailSynchronizer *self,
+                                   const gchar *foldername,
+                                   GHashTable *imap_summaries_tbl,
+                                   GError **err)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	GList *uids_lst = NULL;
@@ -843,15 +843,15 @@ kolab_mail_synchronizer_uid_combine_all (KolabMailSynchronizer *self,
 }
 
 static void
-kolab_mail_synchronizer_record_update_info (KolabMailSynchronizer *self,
-                                            KolabMailAccessOpmodeID opmode,
-                                            KolabMailInfoDbRecord *record,
-                                            const KolabMailSummary *imap_summary,
-                                            const gchar *uid,
-                                            const gchar *foldername,
-                                            KolabFolderTypeID folder_type,
-                                            KolabFolderContextID folder_context,
-                                            gboolean uidval_changed)
+mail_synchronizer_record_update_info (KolabMailSynchronizer *self,
+                                      KolabMailAccessOpmodeID opmode,
+                                      KolabMailInfoDbRecord *record,
+                                      const KolabMailSummary *imap_summary,
+                                      const gchar *uid,
+                                      const gchar *foldername,
+                                      KolabFolderTypeID folder_type,
+                                      KolabFolderContextID folder_context,
+                                      gboolean uidval_changed)
 {
 	/* KolabMailSynchronizerPrivate *priv = NULL; */
 	KolabObjectCacheLocation location = KOLAB_OBJECT_CACHE_LOCATION_INVAL;
@@ -1000,14 +1000,14 @@ kolab_mail_synchronizer_record_update_info (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_uids_infosync (KolabMailSynchronizer *self,
-                                       KolabMailAccessOpmodeID opmode,
-                                       const gchar *foldername,
-                                       const KolabFolderSummary *folder_summary,
-                                       GList *uids_lst,
-                                       GHashTable *imap_summaries_tbl,
-                                       gboolean uidval_changed,
-                                       GError **err)
+mail_synchronizer_uids_infosync (KolabMailSynchronizer *self,
+                                 KolabMailAccessOpmodeID opmode,
+                                 const gchar *foldername,
+                                 const KolabFolderSummary *folder_summary,
+                                 GList *uids_lst,
+                                 GHashTable *imap_summaries_tbl,
+                                 gboolean uidval_changed,
+                                 GError **err)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	GList *uids_lst_ptr = NULL;
@@ -1084,15 +1084,15 @@ kolab_mail_synchronizer_uids_infosync (KolabMailSynchronizer *self,
 
 		/* update InfoDb record data */
 		record_orig = kolab_mail_info_db_record_clone (record);
-		kolab_mail_synchronizer_record_update_info (self,
-		                                            opmode,
-		                                            record,
-		                                            imap_summary,
-		                                            uid,
-		                                            foldername,
-		                                            folder_type,
-		                                            folder_context,
-		                                            uidval_changed);
+		mail_synchronizer_record_update_info (self,
+		                                      opmode,
+		                                      record,
+		                                      imap_summary,
+		                                      uid,
+		                                      foldername,
+		                                      folder_type,
+		                                      folder_context,
+		                                      uidval_changed);
 		/* update InfoDb if record changed */
 		records_eq = kolab_mail_info_db_record_equal (record,
 		                                              record_orig);
@@ -1123,11 +1123,11 @@ kolab_mail_synchronizer_uids_infosync (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_uids_update_infodb (KolabMailSynchronizer *self,
-                                            KolabMailAccessOpmodeID opmode,
-                                            const gchar *foldername,
-                                            GCancellable *cancellable,
-                                            GError **err)
+mail_synchronizer_uids_update_infodb (KolabMailSynchronizer *self,
+                                      KolabMailAccessOpmodeID opmode,
+                                      const gchar *foldername,
+                                      GCancellable *cancellable,
+                                      GError **err)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	GList *folders_lst = NULL;
@@ -1196,10 +1196,10 @@ kolab_mail_synchronizer_uids_update_infodb (KolabMailSynchronizer *self,
 		if (tmp_err != NULL)
 			goto folder_skip;
 
-		uids_lst = kolab_mail_synchronizer_uid_combine_all (self,
-		                                                    foldername,
-		                                                    imap_summaries_tbl,
-		                                                    &tmp_err);
+		uids_lst = mail_synchronizer_uid_combine_all (self,
+		                                              foldername,
+		                                              imap_summaries_tbl,
+		                                              &tmp_err);
 		if (tmp_err != NULL)
 			goto folder_skip;
 
@@ -1216,16 +1216,16 @@ kolab_mail_synchronizer_uids_update_infodb (KolabMailSynchronizer *self,
 		if (tmp_err != NULL)
 			goto folder_skip;
 
-		uidval_chg = kolab_mail_synchronizer_folders_uidvalidity_changed (self,
-		                                                                  folder_summary);
-		ok = kolab_mail_synchronizer_uids_infosync (self,
-		                                            opmode,
-		                                            foldername,
-		                                            folder_summary,
-		                                            uids_lst,
-		                                            imap_summaries_tbl,
-		                                            uidval_chg,
-		                                            &tmp_err);
+		uidval_chg = mail_synchronizer_folders_uidvalidity_changed (self,
+		                                                            folder_summary);
+		ok = mail_synchronizer_uids_infosync (self,
+		                                      opmode,
+		                                      foldername,
+		                                      folder_summary,
+		                                      uids_lst,
+		                                      imap_summaries_tbl,
+		                                      uidval_chg,
+		                                      &tmp_err);
 		if (! ok)
 			goto folder_skip;
 
@@ -1233,8 +1233,8 @@ kolab_mail_synchronizer_uids_update_infodb (KolabMailSynchronizer *self,
 		 * now that we're done walking through that folder's kolab_uids
 		 */
 		if (uidval_chg) {
-			kolab_mail_synchronizer_folders_clear_changed (self,
-			                                               folder_summary);
+			mail_synchronizer_folders_clear_changed (self,
+			                                         folder_summary);
 			ok = kolab_mail_info_db_update_folder_summary (priv->infodb,
 			                                               folder_summary,
 			                                               &tmp_err);
@@ -1262,9 +1262,9 @@ kolab_mail_synchronizer_uids_update_infodb (KolabMailSynchronizer *self,
 }
 
 static gchar*
-kolab_mail_synchronizer_new_free_uid (KolabMailSynchronizer *self,
-                                      GHashTable *summaries,
-                                      GHashTable *changed_uids)
+mail_synchronizer_new_free_uid (KolabMailSynchronizer *self,
+                                GHashTable *summaries,
+                                GHashTable *changed_uids)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	KolabMailSummary *summary = NULL;
@@ -1309,10 +1309,10 @@ kolab_mail_synchronizer_new_free_uid (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_act_on_econtact (EContact *econtact_loc,
-                                         EContact *econtact_srv,
-                                         const gchar *uid,
-                                         const gchar *foldername)
+mail_synchronizer_act_on_econtact (EContact *econtact_loc,
+                                   EContact *econtact_srv,
+                                   const gchar *uid,
+                                   const gchar *foldername)
 {
 	gchar *modtime_loc = NULL;
 	gchar *modtime_srv = NULL;
@@ -1367,10 +1367,10 @@ kolab_mail_synchronizer_act_on_econtact (EContact *econtact_loc,
 }
 
 static gboolean
-kolab_mail_synchronizer_act_on_ecalcomp (ECalComponent *ecalcomp_loc,
-                                         ECalComponent *ecalcomp_srv,
-                                         const gchar *uid,
-                                         const gchar *foldername)
+mail_synchronizer_act_on_ecalcomp (ECalComponent *ecalcomp_loc,
+                                   ECalComponent *ecalcomp_srv,
+                                   const gchar *uid,
+                                   const gchar *foldername)
 {
 	struct icaltimetype itt_loc, *lm_itt_loc = NULL;
 	struct icaltimetype itt_srv, *lm_itt_srv = NULL;
@@ -1425,11 +1425,11 @@ kolab_mail_synchronizer_act_on_ecalcomp (ECalComponent *ecalcomp_loc,
 }
 
 static KolabMailHandle*
-kolab_mail_synchronizer_handle_new_from_record (KolabMailSynchronizer *self,
-                                                const gchar *uid,
-                                                const gchar *foldername,
-                                                const KolabMailInfoDbRecord *record,
-                                                GError **err)
+mail_synchronizer_handle_new_from_record (KolabMailSynchronizer *self,
+                                          const gchar *uid,
+                                          const gchar *foldername,
+                                          const KolabMailInfoDbRecord *record,
+                                          GError **err)
 {
 	/* KolabMailSynchronizerPrivate *priv = NULL; */
 	KolabMailHandle *local_handle = NULL;
@@ -1467,10 +1467,10 @@ kolab_mail_synchronizer_handle_new_from_record (KolabMailSynchronizer *self,
 }
 
 static gboolean
-kolab_mail_synchronizer_push_sidecache (KolabMailSynchronizer *self,
-                                        const gchar *foldername,
-                                        GCancellable *cancellable,
-                                        GError **err)
+mail_synchronizer_push_sidecache (KolabMailSynchronizer *self,
+                                  const gchar *foldername,
+                                  GCancellable *cancellable,
+                                  GError **err)
 {
 	KolabMailSynchronizerPrivate *priv = NULL;
 	GHashTable *imap_summaries =  NULL;
@@ -1532,11 +1532,11 @@ kolab_mail_synchronizer_push_sidecache (KolabMailSynchronizer *self,
 		                                          &tmp_err);
 		if (tmp_err != NULL)
 			goto uid_cleanup;
-		kmailhandle = kolab_mail_synchronizer_handle_new_from_record (self,
-		                                                              uid,
-		                                                              foldername,
-		                                                              record,
-		                                                              &tmp_err);
+		kmailhandle = mail_synchronizer_handle_new_from_record (self,
+		                                                        uid,
+		                                                        foldername,
+		                                                        record,
+		                                                        &tmp_err);
 		if (kmailhandle == NULL)
 			goto uid_cleanup;
 
@@ -1945,17 +1945,17 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 	                                                          &tmp_err);
 	if (tmp_err != NULL)
 		goto cleanup;
-	uidval_changed = kolab_mail_synchronizer_folders_uidvalidity_changed (self,
-	                                                                      folder_summary);
-	kolab_mail_synchronizer_record_update_info (self,
-	                                            opmode,
-	                                            *record,
-	                                            imap_summary,
-	                                            uid,
-	                                            foldername,
-	                                            folder_type,
-	                                            folder_context,
-	                                            uidval_changed);
+	uidval_changed = mail_synchronizer_folders_uidvalidity_changed (self,
+	                                                                folder_summary);
+	mail_synchronizer_record_update_info (self,
+	                                      opmode,
+	                                      *record,
+	                                      imap_summary,
+	                                      uid,
+	                                      foldername,
+	                                      folder_type,
+	                                      folder_context,
+	                                      uidval_changed);
 
 	status = kolab_mail_summary_get_uint_field ((*record)->summary,
 	                                            KOLAB_MAIL_SUMMARY_UINT_FIELD_CACHE_STATUS);
@@ -2003,9 +2003,9 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		changed_uids_tbl = kolab_util_glib_ghashtable_new_from_str_glist (changed_uids_lst);
 		kolab_util_glib_glist_free (changed_uids_lst);
 		changed_uids_lst = NULL;
-		new_uid = kolab_mail_synchronizer_new_free_uid (self,
-		                                                imap_summaries,
-		                                                changed_uids_tbl);
+		new_uid = mail_synchronizer_new_free_uid (self,
+		                                          imap_summaries,
+		                                          changed_uids_tbl);
 		/* set new Kolab UID on handle */
 		ok = kolab_mail_handle_set_uid_full (kmailhandle, new_uid, &tmp_err);
 		if (! ok)
@@ -2138,18 +2138,18 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		case KOLAB_FOLDER_CONTEXT_CONTACT:
 			econtact_loc = kolab_mail_handle_get_econtact (kmh_loc);
 			econtact_srv = kolab_mail_handle_get_econtact (kmh_srv);
-			can_act = kolab_mail_synchronizer_act_on_econtact (econtact_loc,
-			                                                   econtact_srv,
-			                                                   uid,
-			                                                   foldername);
+			can_act = mail_synchronizer_act_on_econtact (econtact_loc,
+			                                             econtact_srv,
+			                                             uid,
+			                                             foldername);
 			break;
 		case KOLAB_FOLDER_CONTEXT_CALENDAR:
 			ecalcomp_loc = kolab_mail_handle_get_ecalcomponent (kmh_loc);
 			ecalcomp_srv = kolab_mail_handle_get_ecalcomponent (kmh_srv);
-			can_act = kolab_mail_synchronizer_act_on_ecalcomp (ecalcomp_loc,
-			                                                   ecalcomp_srv,
-			                                                   uid,
-			                                                   foldername);
+			can_act = mail_synchronizer_act_on_ecalcomp (ecalcomp_loc,
+			                                             ecalcomp_srv,
+			                                             uid,
+			                                             foldername);
 			break;
 		default:
 			g_assert_not_reached ();
@@ -2401,15 +2401,15 @@ kolab_mail_synchronizer_transaction_commit (KolabMailSynchronizer *self,
 	                                                 KOLAB_MAIL_SUMMARY_UINT_FIELD_FOLDER_TYPE);
 	folder_context = kolab_mail_summary_get_uint_field (summary,
 	                                                    KOLAB_MAIL_SUMMARY_UINT_FIELD_FOLDER_CONTEXT);
-	(void)kolab_mail_synchronizer_record_update_info (self,
-	                                                  opmode,
-	                                                  record,
-	                                                  summary,
-	                                                  uid,
-	                                                  foldername,
-	                                                  folder_type,
-	                                                  folder_context,
-	                                                  FALSE);
+	(void)mail_synchronizer_record_update_info (self,
+	                                            opmode,
+	                                            record,
+	                                            summary,
+	                                            uid,
+	                                            foldername,
+	                                            folder_type,
+	                                            folder_context,
+	                                            FALSE);
 
 	location = kolab_mail_summary_get_uint_field (record->summary,
 	                                              KOLAB_MAIL_SUMMARY_UINT_FIELD_CACHE_LOCATION);
@@ -2479,10 +2479,10 @@ kolab_mail_synchronizer_info_sync (KolabMailSynchronizer *self,
 		g_propagate_error (err, tmp_err);
 		return FALSE;
 	}
-	ok = kolab_mail_synchronizer_folders_update_infodb (self,
-	                                                    opmode,
-	                                                    cancellable,
-	                                                    &tmp_err);
+	ok = mail_synchronizer_folders_update_infodb (self,
+	                                              opmode,
+	                                              cancellable,
+	                                              &tmp_err);
 	if (! ok) {
 		ok = kolab_mail_info_db_transaction_abort (priv->infodb, &tmp_err_2);
 		if (! ok) {
@@ -2526,11 +2526,11 @@ kolab_mail_synchronizer_info_sync (KolabMailSynchronizer *self,
 	folders_lst_ptr = folders_lst;
 	while (folders_lst_ptr != NULL) {
 		gchar *fn = (gchar *)(folders_lst_ptr->data);
-		ok = kolab_mail_synchronizer_uids_update_infodb (self,
-		                                                 opmode,
-		                                                 fn,
-		                                                 cancellable,
-		                                                 &tmp_err);
+		ok = mail_synchronizer_uids_update_infodb (self,
+		                                           opmode,
+		                                           fn,
+		                                           cancellable,
+		                                           &tmp_err);
 		if (! ok)
 			break;
 
@@ -2610,10 +2610,10 @@ kolab_mail_synchronizer_full_sync (KolabMailSynchronizer *self,
 	folders_lst_ptr = folders_lst;
 	while (folders_lst_ptr != NULL) {
 		gchar *fn = (gchar *)(folders_lst_ptr->data);
-		ok = kolab_mail_synchronizer_push_sidecache (self,
-		                                             fn,
-		                                             cancellable,
-		                                             &tmp_err);
+		ok = mail_synchronizer_push_sidecache (self,
+		                                       fn,
+		                                       cancellable,
+		                                       &tmp_err);
 		if (! ok) {
 			g_warning ("%s: %s", __func__, tmp_err->message);
 			g_error_free (tmp_err);
