@@ -33,11 +33,11 @@
 #include <glib/gi18n-lib.h>
 
 #include <libical/ical.h>
-#include <libedataserver/e-source.h>
 
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-camel.h>
 
+#include "e-source-kolab-folder.h"
 #include "kolab-mail-access.h"
 
 #include "kolab-util-backend.h"
@@ -77,39 +77,29 @@ kolab_util_backend_error_quark (void)
 }
 
 /*----------------------------------------------------------------------------*/
-/* calendar name <-> folder name translation */
 
-gchar*
-kolab_util_backend_sourcename_new_from_foldername (const gchar *foldername,
-                                                   GError **err)
+/**
+ * kolab_util_backend_get_foldername:
+ * @backend: an #EBackend
+ *
+ * Returns the Kolab foldername for @backend.
+ *
+ * Returns: the foldername for @backend
+ **/
+const gchar *
+kolab_util_backend_get_foldername (EBackend *backend)
 {
-	/* foldername can be NULL */
-	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+	ESource *source;
+	ESourceResource *extension;
+	const gchar *extension_name;
 
-	/* FIXME do input sanitization here, provide real implementation */
+	g_return_val_if_fail (E_IS_BACKEND (backend), NULL);
 
-	/* TODO
-	 * - do we need a full mapping of calendar names to folder names?
-	 * - can we use Camel infrastructure for checking of mailbox names?
-	 */
+	source = e_backend_get_source (backend);
+	extension_name = E_SOURCE_EXTENSION_KOLAB_FOLDER;
+	extension = e_source_get_extension (source, extension_name);
 
-	if (foldername == NULL)
-		return NULL;
-
-	return g_strdup (foldername);
-}
-
-gchar*
-kolab_util_backend_foldername_new_from_sourcename (const gchar *sourcename,
-                                                   GError **err)
-{
-	/* sourcename may be NULL */
-	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
-
-	if (sourcename == NULL)
-		return NULL;
-
-	return g_strdup (sourcename);
+	return e_source_resource_get_identity (extension);
 }
 
 /**
@@ -217,6 +207,29 @@ kolab_util_misc_tls_variant_from_property (const gchar *tls_variant)
 	return tvid;
 } /* kolab_util_misc_tls_variant_from_property () */
 
+gint
+kolab_util_misc_port_number_from_property (const gchar *port_number_prop)
+{
+	gint port = 0;
+
+	if (port_number_prop == NULL)
+		return -1;
+
+	port = kolab_util_misc_generic_integer_from_property (port_number_prop, -1);
+	if (port > 99999) {
+		g_warning ("%s()[%u] configured port number exceeds 5 digits, clamping to 99999!",
+		           __func__, __LINE__);
+		port = 99999;
+	}
+	if (port < 0) {
+		g_warning ("%s()[%u] configured port number is negative, clamping to 0!",
+		           __func__, __LINE__);
+		port = 0;
+	}
+
+	return port;
+}
+
 KolabReqPkcs11
 kolab_util_misc_req_pkcs11_from_property (const gchar *req_pkcs11_prop)
 {
@@ -237,10 +250,12 @@ kolab_util_backend_koma_table_cleanup_cb (gpointer data,
 {
 	KolabMailAccess *koma = KOLAB_MAIL_ACCESS (object);
 	GHashTable *koma_table = (GHashTable *) data;
-	const gchar *servername = NULL;
-	const gchar *username = NULL;
-	gchar *user_at_server = NULL;
+	const gchar *host = NULL;
+	const gchar *user = NULL;
+	gchar *user_at_host = NULL;
 	KolabSettingsHandler *ksettings = NULL;
+	CamelKolabIMAPXSettings *camel_settings;
+	CamelNetworkSettings *network_settings;
 	/* gboolean ok; */
 	g_debug ("%s()[%u] called.", __func__, __LINE__);
 
@@ -249,16 +264,16 @@ kolab_util_backend_koma_table_cleanup_cb (gpointer data,
 	(void)is_last_ref;
 
 	ksettings = kolab_mail_access_get_settings_handler (koma);
-	servername = kolab_settings_handler_get_char_field (ksettings,
-	                                                    KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_SERVER_NAME,
-	                                                    NULL);
-	username = kolab_settings_handler_get_char_field (ksettings,
-	                                                  KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME,
-	                                                  NULL);
-	user_at_server = g_strdup_printf ("%s@%s", username, servername);
-	(void)g_hash_table_remove (koma_table, user_at_server);
+	camel_settings = kolab_settings_handler_get_camel_settings (ksettings);
 
-	g_free (user_at_server);
+	network_settings = CAMEL_NETWORK_SETTINGS (camel_settings);
+	host = camel_network_settings_get_host (network_settings);
+	user = camel_network_settings_get_user (network_settings);
+
+	user_at_host = g_strdup_printf ("%s@%s", user, host);
+	(void)g_hash_table_remove (koma_table, user_at_host);
+
+	g_free (user_at_host);
 	g_object_remove_toggle_ref (object,
 	                            kolab_util_backend_koma_table_cleanup_cb,
 	                            data);
@@ -295,8 +310,6 @@ kolab_util_backend_modtime_set_on_ecalcomp (ECalComponent *ecalcomp)
 void
 kolab_util_backend_prepare_settings (KolabSettingsHandler *ksettings,
                                      ESource *esource,
-                                     const gchar *servername,
-                                     const gchar *username,
                                      const gchar *password,
                                      const gchar *sourcename,
                                      const KolabSyncStrategyID *sync_value)
@@ -306,13 +319,11 @@ kolab_util_backend_prepare_settings (KolabSettingsHandler *ksettings,
 	 * on stdout/stderr and proceeds.
 	 */
 	const gchar *prop_str = NULL;
-	KolabTLSVariantID enc_value;
-	KolabReqPkcs11 req_pkcs11_value;
 
 	GError *error = NULL;
 	g_debug ("%s()[%u] called.", __func__, __LINE__);
 	if (esource != NULL) {
-		prop_str = e_source_peek_uid (esource);
+		prop_str = e_source_get_uid (esource);
 		(void)kolab_settings_handler_set_char_field (ksettings,
 		                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID,
 		                                             g_strdup (prop_str),
@@ -322,66 +333,6 @@ kolab_util_backend_prepare_settings (KolabSettingsHandler *ksettings,
 			g_error_free (error);
 			error = NULL;
 		}
-		prop_str = e_source_get_uri (esource);
-		(void)kolab_settings_handler_set_char_field (ksettings,
-		                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_URI,
-		                                             g_strdup (prop_str),
-		                                             &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-		prop_str = e_source_get_property (esource, KOLAB_TLS_VARIANT_PROP);
-		enc_value = kolab_util_misc_tls_variant_from_property (prop_str);
-		(void)kolab_settings_handler_set_uint_field (ksettings,
-		                                             KOLAB_SETTINGS_HANDLER_UINT_FIELD_TLS_VARIANT,
-		                                             enc_value,
-		                                             &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-		prop_str = e_source_get_property (esource, KOLAB_REQ_PKCS11_PROP);
-		req_pkcs11_value = kolab_util_misc_req_pkcs11_from_property (prop_str);
-		if (req_pkcs11_value == KOLAB_PKCS11_INFRASTRUCTURE_ENABLE) {
-			prop_str = e_source_get_property (esource, KOLAB_PKCS11_PIN_PROP);
-		}
-		else {
-			prop_str = NULL;
-		}
-		(void)kolab_settings_handler_set_char_field (ksettings,
-		                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_PKCS11_USER_PIN,
-		                                             g_strdup (prop_str),
-		                                             &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-	}
-	if (servername != NULL) {
-		(void)kolab_settings_handler_set_char_field (ksettings,
-		                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_SERVER_NAME,
-		                                             g_strdup (servername),
-		                                             &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
-	}
-	if (username != NULL) {
-		(void)kolab_settings_handler_set_char_field (ksettings,
-		                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME,
-		                                             g_strdup (username),
-		                                             &error);
-		if (error != NULL) {
-			g_warning ("%s()[%u] error: %s", __func__, __LINE__, error->message);
-			g_error_free (error);
-			error = NULL;
-		}
 	}
 	if (password != NULL) {
 		(void)kolab_settings_handler_set_char_field (ksettings,
@@ -469,92 +420,14 @@ kolab_util_backend_get_tls_variant_desc (KolabTLSVariantID id)
 	return gettext (kolab_tls_variant_desc[id]);
 }
 
-CamelURL*
-kolab_util_backend_camel_url_new_from_settings (KolabSettingsHandler *ksettings,
-                                                GError **err)
-{
-	KolabTLSVariantID tlsvariant = KOLAB_TLS_VARIANT_NONE;
-	CamelURL *camel_url = NULL;
-	const gchar *variant_str = NULL;
-	const gchar *tmp_str = NULL;
-	GError *tmp_err = NULL;
-
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (ksettings));
-	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
-
-	/* create url string for session getter */
-	camel_url = camel_url_new (KOLAB_CAMELURL_DUMMY_URL, NULL);
-	camel_url_set_protocol (camel_url, KOLAB_CAMEL_PROVIDER_PROTOCOL);
-	tmp_str = kolab_settings_handler_get_char_field (ksettings,
-	                                                 KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_SERVER_NAME,
-	                                                 &tmp_err);
-	if (tmp_err != NULL) {
-		camel_url_free (camel_url);
-		g_propagate_error (err, tmp_err);
-		return NULL;
-	}
-	if (tmp_str == NULL) {
-		camel_url_free (camel_url);
-		/* FIXME mark as a translatable string */
-		g_set_error (err,
-		             KOLAB_BACKEND_ERROR,
-		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "Internal inconsistency detected: Kolab server name not set");
-		return NULL;
-
-	}
-	camel_url_set_host (camel_url, tmp_str);
-	tmp_str = kolab_settings_handler_get_char_field (ksettings,
-	                                                 KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME,
-	                                                 &tmp_err);
-	if (tmp_err != NULL) {
-		camel_url_free (camel_url);
-		g_propagate_error (err, tmp_err);
-		return NULL;
-	}
-	if (tmp_str == NULL) {
-		camel_url_free (camel_url);
-		/* FIXME mark as a translatable string */
-		g_set_error (err,
-		             KOLAB_BACKEND_ERROR,
-		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "Internal inconsistency detected: Kolab User ID not set");
-		return NULL;
-
-	}
-	camel_url_set_user (camel_url, tmp_str);
-	tlsvariant = kolab_settings_handler_get_uint_field (ksettings,
-	                                                    KOLAB_SETTINGS_HANDLER_UINT_FIELD_TLS_VARIANT,
-	                                                    &tmp_err);
-	if (tmp_err != NULL) {
-		camel_url_free (camel_url);
-		g_propagate_error (err, tmp_err);
-		return NULL;
-	}
-
-	switch (tlsvariant) {
-	case KOLAB_TLS_VARIANT_SSL:
-		variant_str = KOLAB_CAMELURL_TLSVARIANT_SSL;
-		break;
-	case KOLAB_TLS_VARIANT_STARTTLS:
-		variant_str = KOLAB_CAMELURL_TLSVARIANT_STARTTLS;
-		break;
-	default:
-		variant_str = KOLAB_CAMELURL_TLSVARIANT_NONE;
-	}
-
-	camel_url_set_param (camel_url,
-	                     KOLAB_CAMELURL_PARAM_SSL,
-	                     variant_str);
-	return camel_url;
-}
-
 gchar*
 kolab_util_backend_account_uid_new_from_settings (KolabSettingsHandler *ksettings,
                                                   GError **err)
 {
+	CamelKolabIMAPXSettings *camel_settings;
+	CamelNetworkSettings *network_settings;
+	const gchar *host = NULL;
 	const gchar *user = NULL;
-	const gchar *server = NULL;
 	const gchar *esource_uid = NULL;
 	gchar *account_uid = NULL;
 	gchar *tmp_str = NULL;
@@ -579,22 +452,13 @@ kolab_util_backend_account_uid_new_from_settings (KolabSettingsHandler *ksetting
 
 	/* fallback in case we don't have an ESource UID set */
 
-	user = kolab_settings_handler_get_char_field (ksettings,
-	                                              KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME,
-	                                              &tmp_err);
-	if (tmp_err != NULL) {
-		g_propagate_error (err, tmp_err);
-		return NULL;
-	}
-	server = kolab_settings_handler_get_char_field (ksettings,
-	                                                KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_SERVER_NAME,
-	                                                &tmp_err);
-	if (tmp_err != NULL) {
-		g_propagate_error (err, tmp_err);
-		return NULL;
-	}
+	camel_settings = kolab_settings_handler_get_camel_settings (ksettings);
 
-	tmp_str = g_strconcat (user, "@", server, NULL);
+	network_settings = CAMEL_NETWORK_SETTINGS (camel_settings);
+	host = camel_network_settings_get_host (network_settings);
+	user = camel_network_settings_get_user (network_settings);
+
+	tmp_str = g_strconcat (user, "@", host, NULL);
 
  done:
 
