@@ -28,7 +28,7 @@
 #include <stdio.h>
 #include <unistd.h> /* getcwd() definition */
 #include <sys/param.h> /* MAXPATHLEN definition */
-#include <libecal/e-cal-component.h>
+#include <libecal/libecal.h>
 #include <kolab-conv.h>
 #include <evolution/evolution.h>
 #include <kolab/kolab.h>
