@@ -98,7 +98,7 @@ kolab_util_camel_get_storage_path (CamelService *service,
 		g_set_error (err,
 		             KOLAB_CAMEL_KOLAB_ERROR,
 		             KOLAB_CAMEL_KOLAB_ERROR_DB,
-		             "Could not get Camel storage path");
+		             _("Could not get Camel storage path"));
 	}
 
 	return store_path;
