@@ -161,4 +161,58 @@ kolab_util_glib_string_gcompare (gconstpointer a,
 	return g_strcmp0 (str_a, str_b);
 }
 
+void
+kolab_util_glib_gconstlist_free (KolabGConstList *list)
+{
+	KolabGConstList *anchor = NULL;
+	KolabGConstList *ptr = NULL;
+
+	if (list == NULL)
+		return;
+
+	anchor = list;
+	ptr = list->next;
+
+	while (ptr != NULL) {
+		g_free (anchor);
+		anchor = ptr;
+		ptr = anchor->next;
+	}
+	g_free (anchor);
+}
+
+KolabGConstList*
+kolab_util_glib_gconstlist_prepend (KolabGConstList *list, gconstpointer data)
+{
+	KolabGConstList *elem = g_new0 (KolabGConstList, 1);
+
+	elem->const_data = data;
+	elem->next = list;
+	if (list != NULL)
+		list->prev = elem;
+
+	return elem;
+}
+
+KolabGConstList*
+kolab_util_glib_gconstlist_append (KolabGConstList *list, gconstpointer data)
+{
+	KolabGConstList *elem = g_new0 (KolabGConstList, 1);
+	KolabGConstList *ptr = NULL;
+
+	elem->const_data = data;
+
+	if (list == NULL)
+		return elem;
+
+	ptr = list;
+	while (ptr->next != NULL)
+		ptr = ptr->next;
+
+	ptr->next = elem;
+	elem->prev = ptr;
+
+	return list;
+}
+
 /*----------------------------------------------------------------------------*/
