@@ -230,10 +230,10 @@ kolab_util_http_soup_get (const KolabUtilHttpJob *job, GError **error)
 /* LibCurl */
 
 static size_t
-kolab_util_http_curl_writefunc (const void *data,
-                                const size_t size,
-                                const size_t nmemb,
-                                void *stream)
+util_http_curl_writefunc (const void *data,
+                          const size_t size,
+                          const size_t nmemb,
+                          void *stream)
 {
 	GByteArray *buffer = (GByteArray*) stream;
 	size_t nbytes = size * nmemb;
@@ -246,7 +246,7 @@ kolab_util_http_curl_writefunc (const void *data,
 }
 
 static CURLcode
-kolab_util_http_curl_set_genopts (void)
+util_http_curl_set_genopts (void)
 {
 	/* TODO change this to table-based for-loop */
 	CURLcode curlcode; /* can't bit-or this... */
@@ -268,7 +268,7 @@ kolab_util_http_curl_set_genopts (void)
 	if (curlcode) return curlcode;
 	curlcode = curl_easy_setopt (kolab_curl_handle,
 	                             CURLOPT_WRITEFUNCTION,
-	                             kolab_util_http_curl_writefunc);
+	                             util_http_curl_writefunc);
 	if (curlcode) return curlcode;
 	curlcode = curl_easy_setopt (kolab_curl_handle,
 	                             CURLOPT_HTTPAUTH,
@@ -298,7 +298,7 @@ kolab_util_http_curl_set_genopts (void)
 }
 
 static CURLcode
-kolab_util_http_curl_set_jobopts (const KolabUtilHttpJob *job)
+util_http_curl_set_jobopts (const KolabUtilHttpJob *job)
 {
 	CURLcode curlcode;
 	gchar *usrpwd = NULL;
@@ -369,7 +369,7 @@ kolab_util_http_curl_set_jobopts (const KolabUtilHttpJob *job)
 }
 
 static gssize
-kolab_util_http_curl_get (KolabUtilHttpJob *job, GError **error)
+util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 {
 	gssize nbytes = -1;
 	CURLcode curlcode;
@@ -377,7 +377,7 @@ kolab_util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 
 	g_return_val_if_fail (error == NULL || *error == NULL, -1);
 	/* curl job setup */
-	curlcode = kolab_util_http_curl_set_jobopts (job);
+	curlcode = util_http_curl_set_jobopts (job);
 	if (curlcode) {
 		g_set_error (error,
 		             KOLAB_UTIL_HTTP_ERROR,
@@ -459,7 +459,7 @@ kolab_util_http_init (void)
 
 	kolab_curl_handle = curl_easy_init ();
 	g_assert (kolab_curl_handle != NULL);
-	kolab_util_http_curl_set_genopts ();
+	util_http_curl_set_genopts ();
 	http_is_initialized = TRUE;
 }
 
@@ -507,7 +507,7 @@ kolab_util_http_get (KolabUtilHttpJob *job, GError **error)
 {
 	gssize nbytes = -1;
 
-	nbytes = kolab_util_http_curl_get (job, error);
+	nbytes = util_http_curl_get (job, error);
 
 #if 0
 	/* TODO change this to conditional compilation once
